<?php
// Italian language file contributed by Tiraboschi Massimiliano aka TiMax  
// www.maxdev.com  timax@maxdev.com
$ADODB_LANG_ARRAY = array (
            'LANG'                      => 'it',
            DB_ERROR                    => 'errore sconosciuto',
            DB_ERROR_ALREADY_EXISTS     => 'esiste gi&agrave;',
            DB_ERROR_CANNOT_CREATE      => 'non posso creare',
            DB_ERROR_CANNOT_DELETE      => 'non posso cancellare',
            DB_ERROR_CANNOT_DROP        => 'non posso eliminare',
            DB_ERROR_CONSTRAINT         => 'violazione constraint',
            DB_ERROR_DIVZERO            => 'divisione per zero',
            DB_ERROR_INVALID            => 'non valido',
            DB_ERROR_INVALID_DATE       => 'data od ora non valida',
            DB_ERROR_INVALID_NUMBER     => 'numero non valido',
            DB_ERROR_MISMATCH           => 'diversi',
            DB_ERROR_NODBSELECTED       => 'nessun database selezionato',
            DB_ERROR_NOSUCHFIELD        => 'nessun campo trovato',
            DB_ERROR_NOSUCHTABLE        => 'nessuna tabella trovata',
            DB_ERROR_NOT_CAPABLE        => 'DB backend non abilitato',
            DB_ERROR_NOT_FOUND          => 'non trovato',
            DB_ERROR_NOT_LOCKED         => 'non bloccato',
            DB_ERROR_SYNTAX             => 'errore di sintassi',
            DB_ERROR_UNSUPPORTED        => 'non supportato',
            DB_ERROR_VALUE_COUNT_ON_ROW => 'valore inserito troppo grande per una colonna',
            DB_ERROR_INVALID_DSN        => 'DSN non valido',
            DB_ERROR_CONNECT_FAILED     => 'connessione fallita',
            0                           => 'nessun errore', // DB_OK
            DB_ERROR_NEED_MORE_DATA     => 'dati inseriti insufficienti',
            DB_ERROR_EXTENSION_NOT_FOUND=> 'estensione non trovata',
            DB_ERROR_NOSUCHDB           => 'database non trovato',
            DB_ERROR_ACCESS_VIOLATION   => 'permessi insufficienti'
);
?>