<?php
	/**
	 * Greek language file.
	 */

	//Basic
	$plugin_lang['strplugindescription'] = 'Report plugin';
	$plugin_lang['strnoreportsdb'] = 'Η βάση αναφορών δεν έχει δημιουργηθεί. Διαβάστε το αρχείο INSTALL για οδηγίες.';

	// Reports
	$plugin_lang['strreport'] = 'Αναφορά';
	$plugin_lang['strreports'] = 'Αναφορές';
	$plugin_lang['strshowallreports'] = 'Εμφάνιση όλων των αναφορών';
	$plugin_lang['strnoreports'] = 'Δε βρέθηκαν αναφορές.';
	$plugin_lang['strcreatereport'] = 'Δημιουργία αναφοράς';
	$plugin_lang['strreportdropped'] = 'Η αναφορά διαγράφηκε.';
	$plugin_lang['strreportdroppedbad'] = 'Η διαγραφή της αναφοράς απέτυχε.';
	$plugin_lang['strconfdropreport'] = 'Να διαγραφεί η αναφορά "%s"?';
	$plugin_lang['strreportneedsname'] = 'Πρέπει να δώσετε όνομα στην αναφορά.';
	$plugin_lang['strreportneedsdef'] = 'Πρέπει να δώσετε SQL για την αναφορά.';
	$plugin_lang['strreportcreated'] = 'Η αναφορά αποθηκεύτηκε.';
	$plugin_lang['strreportcreatedbad'] = 'Η αποθήκευση της αναφοράς απέτυχε.';

?>
