<?php
	/**
	 * Italian language file.
	 */

	//Basic
	$plugin_lang['strplugindescription'] = 'Report plugin';
	$plugin_lang['strnoreportsdb'] = 'Non è stato creato il database dei report. Leggere il file INSTALL per istruzioni.';

	// Reports - Rapporti
	$plugin_lang['strreport'] = 'Rapporto';
	$plugin_lang['strreports'] = 'Rapporti';
	$plugin_lang['strshowallreports'] = 'Mostra tutti i rapporti';
	$plugin_lang['strnoreports'] = 'Nessun rapporto trovato.';
	$plugin_lang['strcreatereport'] = 'Crea rapporto';
	$plugin_lang['strreportdropped'] = 'Rapporto eliminato.';
	$plugin_lang['strreportdroppedbad'] = 'Eliminazione del rapporto fallita.';
	$plugin_lang['strconfdropreport'] = 'Eliminare il rapporto "%s"?';
	$plugin_lang['strreportneedsname'] = 'È necessario specificare un nome per il rapporto.';
	$plugin_lang['strreportneedsdef'] = 'È necessario inserire il codice SQL per il rapporto.';
	$plugin_lang['strreportcreated'] = 'Rapporto salvato';
	$plugin_lang['strreportcreatedbad'] = 'Salvataggio del rapporto fallito.';
?>
