<?php
    /**
     * Arabic language file.
     */

    // Basic strings
    $plugin_lang['strplugindescription'] = 'Report plugin';
    $plugin_lang['strnoreportsdb'] = 'لم تقم بإنشاء قاعدة بيانات التقارير reports database. إقرأ التعليمات في المف INSTALL.';

    // Reports
    $plugin_lang['strreport'] = 'تقرير Report';
    $plugin_lang['strreports'] = 'تقارير Reports';
    $plugin_lang['strshowallreports'] = 'عرض جميع التقارير';
    $plugin_lang['strnoreports'] = 'لم توجد تقارير.';
    $plugin_lang['strcreatereport'] = 'إنشاء تقرير جديد';
    $plugin_lang['strreportdropped'] = 'تم حذف التقرير.';
    $plugin_lang['strreportdroppedbad'] = 'فشلت عملية حذف التقرير.';
    $plugin_lang['strconfdropreport'] = 'هل أنت متأكد تريد حذف التقرير "%s"؟';
    $plugin_lang['strreportneedsname'] = 'يجب إعطاء اسم للتقرير.';
    $plugin_lang['strreportneedsdef'] = 'يجب كتابة عبارة SQL للتقرير.';
    $plugin_lang['strreportcreated'] = 'تم حفظ التقرير.';
    $plugin_lang['strreportcreatedbad'] = 'لم يتم حفظ التقرير، لقد فشلت عملية الحفظ.';
?>
