<?php

	/**
	 * Polish language file for WebDB.
	 * @maintainer Rafal Slubowski [slubek@users.sourceforge.net]
	 *
	 * $Id: polish.php,v 1.55 2007/04/24 11:42:07 soranzo Exp $
	 */

	// Language and character set
	$lang['applang'] = 'Polski';
	$lang['applocale'] = 'pl-PL';
	$lang['applangdir'] = 'ltr';

	// Welcome
	$lang['strintro'] = 'Witaj w phpPgAdmin.';
	$lang['strppahome'] = 'Strona domowa phpPgAdmin';
	$lang['strpgsqlhome'] = 'Strona domowa PostgreSQL';
	$lang['strpgsqlhome_url'] = 'http://www.postgresql.org/';
	$lang['strlocaldocs'] = 'Dokumentacja PostgreSQL (lokalna)';
	$lang['strreportbug'] = 'Zgłoś raport o błędzie';
	$lang['strviewfaq'] = 'Przejrzyj FAQ';
	$lang['strviewfaq_url'] = 'http://phppgadmin.sourceforge.net/doku.php?id=faq';

	// Basic strings
	$lang['strlogin'] = 'Zaloguj';
	$lang['strloginfailed'] = 'Próba zalogowania nie powiodła się.';
	$lang['strlogindisallowed'] = 'Logowanie niedozwolone';
	$lang['strserver'] = 'Serwer';
	$lang['strservers'] = 'Serwery';
	$lang['strintroduction'] = 'Wprowadzenie';
	$lang['strhost'] = 'Host';
	$lang['strport'] = 'Port';
	$lang['strlogout'] = 'Wyloguj się';
	$lang['strowner'] = 'Właściciel';
	$lang['straction'] = 'Akcja';	
	$lang['stractions'] = 'Akcje';	
	$lang['strname'] = 'Nazwa';
	$lang['strdefinition'] = 'Definicja';
	$lang['strproperties'] = 'Właściwości';
	$lang['strbrowse'] = 'Przeglądaj';
	$lang['strenable']  =  'Aktywuj';
	$lang['strdisable']  =  'Deaktywuj';
	$lang['strdrop'] = 'Usuń';
	$lang['strdropped'] = 'Usunięty';
	$lang['strnull'] = 'Null';
	$lang['strnotnull'] = 'Not Null';
	$lang['strprev'] = 'Poprzedni';
	$lang['strnext'] = 'Następny';
	$lang['strfirst'] = '<< Pierwszy';
	$lang['strlast'] = 'Ostatni >>';
	$lang['strfailed'] = 'Nieudany';
	$lang['strcreate'] = 'Utwórz';
	$lang['strcreated'] = 'Utworzony';
	$lang['strcomment'] = 'Komentarz';
	$lang['strlength'] = 'Długość';
	$lang['strdefault'] = 'Domyślny';
	$lang['stralter'] = 'Zmień';
	$lang['strok'] = 'OK';
	$lang['strcancel'] = 'Anuluj';
	$lang['strac']  =  'Włącz autouzupełnianie';
	$lang['strsave'] = 'Zapisz';
	$lang['strreset'] = 'Wyczyść';
	$lang['strinsert'] = 'Wstaw';
	$lang['strselect'] = 'Wybierz';
	$lang['strdelete'] = 'Usuń';
	$lang['strupdate'] = 'Zmień';
	$lang['strreferences'] = 'Odnośniki';
	$lang['stryes'] = 'Tak';
	$lang['strno'] = 'Nie';
	$lang['strtrue'] = 'Prawda';
	$lang['strfalse'] = 'Fałsz';
	$lang['stredit'] = 'Edycja';
	$lang['strcolumn'] = 'Kolumna';
	$lang['strcolumns'] = 'Kolumny';
	$lang['strrows'] = 'wiersz(y)';
	$lang['strrowsaff'] = 'wiersz(y) dotyczy.';
	$lang['strobjects'] = 'obiekty';
	$lang['strback'] = 'Wstecz';
	$lang['strqueryresults'] = 'Wyniki zapytania';
	$lang['strshow'] = 'Pokaż';
	$lang['strempty'] = 'Wyczyść';
	$lang['strlanguage'] = 'Język';
	$lang['strencoding'] = 'Kodowanie';
	$lang['strvalue'] = 'Wartość';
	$lang['strunique'] = 'Unikatowy';
	$lang['strprimary'] = 'Główny';
	$lang['strexport'] = 'Eksport';
	$lang['strimport'] = 'Import';
	$lang['strallowednulls'] = 'Dozwolone znaki NULL';
	$lang['strbackslashn'] = '\N';
	$lang['strnull'] = 'Null';
	$lang['stremptystring'] = 'Pusty ciąg znaków/pole';
	$lang['strsql'] = 'SQL';
	$lang['stradmin'] = 'Administruj';
	$lang['strvacuum'] = 'Przeczyść';
	$lang['stranalyze'] = 'Analizuj';
	$lang['strclusterindex'] = 'Klastruj';
	$lang['strclustered'] = 'Klastrowany?';
	$lang['strreindex'] = 'Przeindeksuj';
	$lang['strrun'] = 'Uruchom';
	$lang['stradd'] = 'Dodaj';
	$lang['strremove'] = 'Usuń';
	$lang['strevent'] = 'Zdarzenie';
	$lang['strwhere'] = 'Gdzie';
	$lang['strinstead'] = 'Wykonaj zamiast';
	$lang['strwhen'] = 'Kiedy';
	$lang['strformat'] = 'Format';
	$lang['strdata'] = 'Dane';
	$lang['strconfirm'] = 'Potwierdź';
	$lang['strexpression'] = 'Wyrażenie';
	$lang['strellipsis'] = '...';
	$lang['strseparator'] = ': ';
	$lang['strexpand'] = 'Rozwiń';
	$lang['strcollapse'] = 'Zwiń';
	$lang['strexplain'] = 'Explain';
	$lang['strexplainanalyze'] = 'Explain Analyze';
	$lang['strfind'] = 'Znajdź';
	$lang['stroptions'] = 'Opcje';
	$lang['strrefresh'] = 'Odśwież';
	$lang['strdownload'] = 'Pobierz';
	$lang['strdownloadgzipped'] = 'Pobierz skompresowane gzip-em';
	$lang['strinfo'] = 'Informacje';
	$lang['stroids'] = 'OIDy';
	$lang['stradvanced'] = 'Zaawansowane';
	$lang['strvariables'] = 'Zmienne';
	$lang['strprocess'] = 'Proces';
	$lang['strprocesses'] = 'Procesy';
	$lang['strsetting'] = 'Ustawienie';
	$lang['streditsql'] = 'Edycja zapytania SQL';
	$lang['strruntime'] = 'Całkowity czas pracy: %s ms.';
	$lang['strpaginate'] = 'Wyświetl wyniki stronami';
	$lang['struploadscript'] = 'lub załaduj skrypt SQL:';
	$lang['strstarttime'] = 'Czas początku';
	$lang['strfile'] = 'Plik';
	$lang['strfileimported'] = 'Plik został zaimportowany.';
	$lang['strtrycred'] = 'Użyj tych parametrów dla wszystkich serwerów';
	$lang['strexecute'] = 'Wykonaj';

	// Database Sizes
	$lang['strsize'] = 'Rozmiar';
	$lang['strbytes'] = 'bajtów';
	$lang['strkb'] = 'kB';
	$lang['strmb'] = 'MB';
	$lang['strgb'] = 'GB';
	$lang['strtb'] = 'TB';

	// Error handling
	$lang['strnoframes'] = 'Ta aplikacja najlepiej działa w przeglądarce obsługującej ramki, ale możesz jej użyć również bez ramek, klikając poniższy link.';
	$lang['strnoframeslink'] = 'Otwórz bez ramek';
	$lang['strbadconfig'] = 'Twój plik config.inc.php jest przestarzały. Musisz go utworzyć ponownie wykorzystując nowy config.inc.php-dist.';
	$lang['strnotloaded'] = 'Nie wkompilowałeś do PHP obsługi tej bazy danych.';
	$lang['strpostgresqlversionnotsupported'] = 'Nieobsługiwana wersja PostgreSQL. Uaktualnij do wersji %s lub nowszej.';
	$lang['strbadschema'] = 'Podano błędny schemat.';
	$lang['strbadencoding'] = 'Błędne kodowanie bazy.';
	$lang['strsqlerror'] = 'Błąd SQL:';
	$lang['strinstatement'] = 'W poleceniu:';
	$lang['strinvalidparam'] = 'Błędny parametr.';
	$lang['strnodata'] = 'Nie znaleziono danych.';
	$lang['strnoobjects'] = 'Nie znaleziono obiektów.';
	$lang['strrownotunique'] = 'Brak unikatowego identyfikatora dla tego wiersza.';
	$lang['strnouploads'] = 'Ładowanie plików wyłączone.';
	$lang['strimporterror'] = 'Błąd importu.';
	$lang['strimporterror-fileformat'] = 'Błąd importu: Nie można automatycznie określić formatu pliku.';
	$lang['strimporterrorline'] = 'Błąd importu w linii %s.';
	$lang['strimporterrorline-badcolumnnum'] = 'Błąd importu w linii %s: Linia nie ma właściwej liczby kolumn.';
	$lang['strimporterror-uploadedfile'] = 'Błąd importu: plik nie może być załadowany na serwer.';
	$lang['strcannotdumponwindows'] = 'Zrzucanie złożonych nazw tabel i schematów pod Windows jest nie wspierane.';

	// Tables
	$lang['strtable'] = 'Tabela';
	$lang['strtables'] = 'Tabele';
	$lang['strshowalltables'] = 'Pokaż wszystkie tabele';
	$lang['strnotables'] = 'Nie znaleziono tabel.';
	$lang['strnotable'] = 'Nie znaleziono tabeli.';
	$lang['strcreatetable'] = 'Utwórz tabelę';
	$lang['strtablename'] = 'Nazwa tabeli';
	$lang['strtableneedsname'] = 'Musisz nazwać tabelę.';
	$lang['strtableneedsfield'] = 'Musisz podać przynajmniej jedno pole.';
	$lang['strtableneedscols'] = 'Musisz podać prawidłową liczbę kolumn.';
	$lang['strtablecreated'] = 'Tabela została utworzona.';
	$lang['strtablecreatedbad'] = 'Próba utworzenia tabeli się nie powiodła.';
	$lang['strconfdroptable'] = 'Czy na pewno chcesz usunąć tabelę "%s"?';
	$lang['strtabledropped'] = 'Tabela została usunięta.';
	$lang['strtabledroppedbad'] = 'Próba usunięcia tabeli się nie powiodła.';
	$lang['strconfemptytable'] = 'Czy na pewno chcesz wyczyścić tabelę "%s"?';
	$lang['strtableemptied'] = 'Tabela została wyczyszczona.';
	$lang['strtableemptiedbad'] = 'Próba wyczyszczenia tabeli się nie powiodła.';
	$lang['strinsertrow'] = 'Wstaw wiersz';
	$lang['strrowinserted'] = 'Wiersz został wstawiony.';
	$lang['strrowinsertedbad'] = 'Próba wstawienia wiersza się nie powiodła.';
	$lang['strrowduplicate'] = 'Próba wstawienia zduplikowanego wiersza.';
	$lang['streditrow'] = 'Edycja wiersza';
	$lang['strrowupdated'] = 'Wiersz został zaktualizowany.';
	$lang['strrowupdatedbad'] = 'Próba aktualizacji wiersza się nie powiodła.';
	$lang['strdeleterow'] = 'Usuń wiersz';
	$lang['strconfdeleterow'] = 'Czy na pewno chcesz usunąć ten wiersz?';
	$lang['strrowdeleted'] = 'Wiersz został usunięty.';
	$lang['strrowdeletedbad'] = 'Próba usunięcia wiersza się nie powiodła.';
	$lang['strinsertandrepeat'] = 'Wstaw i powtórz';
	$lang['strnumcols'] = 'Ilość kolumn';
	$lang['strcolneedsname'] = 'Musisz podać nazwę kolumny.';
	$lang['strselectallfields'] = 'Wybierz wszystkie pola';
	$lang['strselectneedscol'] = 'Musisz wybrać przynajmniej jedną kolumnę.';
	$lang['strselectunary'] = 'Operatory bezargumentowe (IS NULL/IS NOT NULL) nie mogą mieć podanej wartości.';
	$lang['straltercolumn'] = 'Zmień kolumnę';
	$lang['strcolumnaltered'] = 'Kolumna została zmodyfikowana.';
	$lang['strcolumnalteredbad'] = 'Próba modyfikacji kolumny się nie powiodła.';
	$lang['strconfdropcolumn'] = 'Czy na pewno chcesz usunąć kolumnę "%s" z tabeli "%s"?';
	$lang['strcolumndropped'] = 'Kolumna została usunięta.';
	$lang['strcolumndroppedbad'] = 'Próba usunięcia kolumny się nie powiodła.';
	$lang['straddcolumn'] = 'Dodaj kolumnę';
	$lang['strcolumnadded'] = 'Kolumna została dodana.';
	$lang['strcolumnaddedbad'] = 'Próba dodania kolumny się nie powiodła.';
	$lang['strcascade'] = 'CASCADE';
	$lang['strtablealtered'] = 'Tabela została zmodyfikowana.';
	$lang['strtablealteredbad'] = 'Próba modyfikacji tabeli się nie powiodła.';
	$lang['strdataonly'] = 'Tylko dane';
	$lang['strstructureonly'] = 'Tylko struktura';
	$lang['strstructureanddata'] = 'Struktura i dane';
	$lang['strtabbed'] = 'Z tabulacjami';
	$lang['strauto'] = 'Automatyczny';
	$lang['strconfvacuumtable'] = 'Czy na pewno chcesz wykonać vacuum "%s"?';
	$lang['strestimatedrowcount'] = 'Przybliżona ilość wierszy';

	// Columns
	$lang['strcolprop']  =  'Właściwości kolumny';
		
	// Users
	$lang['struser'] = 'Użytkownik';
	$lang['strusers'] = 'Użytkownicy';
	$lang['strusername'] = 'Nazwa użytkownika';
	$lang['strpassword'] = 'Hasło';
	$lang['strsuper'] = 'Administrator?';
	$lang['strcreatedb'] = 'Tworzenie BD?';
	$lang['strexpires'] = 'Wygasa';	
	$lang['strsessiondefaults'] = 'Wartości domyślne sesji';
	$lang['strnousers'] = 'Nie znaleziono użytkowników.';
	$lang['struserupdated'] = 'Parametry użytkownika zostały zaktualizowane.';
	$lang['struserupdatedbad'] = 'Próba aktualizacji parametrów użytkownika się nie powiodła.';
	$lang['strshowallusers'] = 'Pokaż wszystkich użytkowników';
	$lang['strcreateuser'] = 'Utwórz użytkownika';
	$lang['struserneedsname'] = 'Musisz podać nazwę użytkownika.';
	$lang['strusercreated'] = 'Użytkownik został utworzony.';
	$lang['strusercreatedbad'] = 'Próba utworzenia użytkownika się nie powiodła.';
	$lang['strconfdropuser'] = 'Czy na pewno chcesz usunąć użytkownika "%s"?';
	$lang['struserdropped'] = 'Użytkownik został usunięty.';
	$lang['struserdroppedbad'] = 'Próba usunięcia użytkownika się nie powiodła.';
	$lang['straccount'] = 'Konto';
	$lang['strchangepassword'] = 'Zmień hasło';
	$lang['strpasswordchanged'] = 'Hasło zostało zmienione.';
	$lang['strpasswordchangedbad'] = 'Próba zmiany hasła się nie powiodła.';
	$lang['strpasswordshort'] = 'Hasło jest za krótkie.';
	$lang['strpasswordconfirm'] = 'Hasło i potwierdzenie muszą być takie same.';
	
	// Groups
	$lang['strgroup'] = 'Grupa';
	$lang['strgroups'] = 'Grupy';
	$lang['strnogroup'] = 'Nie znaleziono grupy.';
	$lang['strnogroups'] = 'Nie znaleziono grup.';
	$lang['strcreategroup'] = 'Utwórz grupę';
	$lang['strshowallgroups'] = 'Pokaż wszystkie grupy';
	$lang['strgroupneedsname'] = 'Musisz nazwać grupę.';
	$lang['strgroupcreated'] = 'Grupa została utworzona.';
	$lang['strgroupcreatedbad'] = 'Próba utworzenia grupy się nie powiodła.';
	$lang['strconfdropgroup'] = 'Czy na pewno chcesz utworzyć grupę "%s"?';
	$lang['strgroupdropped'] = 'Grupa została usunięta.';
	$lang['strgroupdroppedbad'] = 'Próba usunięcia grupy się nie powiodła.';
	$lang['strmembers'] = 'Członkowie';
	$lang['straddmember'] = 'Dodaj członka grupy';
	$lang['strmemberadded'] = 'Członek grupy został dodany.';
	$lang['strmemberaddedbad'] = 'Próba dodania członka grupy się nie powiodła.';
	$lang['strdropmember'] = 'Usuń członka grupy';
	$lang['strconfdropmember'] = 'Czy na pewno chcesz usunąć "%s" z grupy "%s"?';
	$lang['strmemberdropped'] = 'Członek grupy został usunięty.';
	$lang['strmemberdroppedbad'] = 'Próba usunięcia członka grupy się nie powiodła.';

	// Roles
	$lang['strrole'] = 'Rola';
	$lang['strroles'] = 'Role';
	$lang['strinheritsprivs'] = 'Dziedziczyć uprawnienia?';
	$lang['strcreaterole'] = 'Utwórz rolę';
	$lang['strcatupdate'] = 'Modyfikacja katalogów?';
	$lang['strcanlogin'] = 'Może się logować?';
	$lang['strmaxconnections'] = 'Maks. ilość połączeń';
	$lang['strconfdroprole'] = 'Czy na pewno chcesz usunąć rolę "%s"?';
	$lang['strroledropped'] = 'Rola została usunięta.';
	$lang['strroledroppedbad'] = 'Próba usunięcia roli się nie powiodła.';
	
	// Privileges
	$lang['strprivilege'] = 'Uprawnienie';
	$lang['strprivileges'] = 'Uprawnienia';
	$lang['strnoprivileges'] = 'Ten obiekt nie ma uprawnień.';
	$lang['strgrant'] = 'Nadaj';
	$lang['strrevoke'] = 'Zabierz';
	$lang['strgranted'] = 'Uprawnienia zostały nadane.';
	$lang['strgrantfailed'] = 'Próba nadania uprawnień się nie powiodła.';
	$lang['strgrantbad'] = 'Musisz podać użytkownika lub grupę, a także uprawnienia, jakie chcesz nadać.';
	$lang['strgrantor'] = 'Kto nadał';
	$lang['strasterisk'] = '*';

	// Databases
	$lang['strdatabase'] = 'Baza danych';
	$lang['strdatabases'] = 'Bazy danych';
	$lang['strshowalldatabases'] = 'Pokaż wszystkie bazy danych';
	$lang['strnodatabase'] = 'Nie znaleziono bazy danych.';
	$lang['strnodatabases'] = 'Nie znaleziono żadnej bazy danych.';
	$lang['strcreatedatabase'] = 'Utwórz bazę danych';
	$lang['strdatabasename'] = 'Nazwa bazy danych';
	$lang['strdatabaseneedsname'] = 'Musisz nazwać bazę danych.';
	$lang['strdatabasecreated'] = 'Baza danych została utworzona.';
	$lang['strdatabasecreatedbad'] = 'Próba utworzenia bazy danych się nie powiodła.';
	$lang['strconfdropdatabase'] = 'Czy na pewno chcesz usunąć bazę danych "%s"?';
	$lang['strdatabasedropped'] = 'Baza danych została usunięta.';
	$lang['strdatabasedroppedbad'] = 'Próba usunięcia bazy danych się nie powiodła.';
	$lang['strentersql'] = 'Podaj polecenie SQL do wykonania:';
	$lang['strsqlexecuted'] = 'Polecenie SQL zostało wykonane.';
	$lang['strvacuumgood'] = 'Czyszczenie bazy zostało zakończone.';
	$lang['strvacuumbad'] = 'Próba czyszczenia bazy się nie powiodła.';
	$lang['stranalyzegood'] = 'Analiza bazy została zakończona.';
	$lang['stranalyzebad'] = 'Próba analizy się nie powiodła.';
	$lang['strreindexgood'] = 'Reindeksacja została zakończona.';
	$lang['strreindexbad'] = 'Próba reindeksacji się nie powiodła.';
	$lang['strfull'] = 'Pełne';
	$lang['strfreeze'] = 'Zamrożenie';
	$lang['strforce'] = 'Wymuszenie';
	$lang['strsignalsent'] = 'Sygnał został wysłany.';
	$lang['strsignalsentbad'] = 'Próba wysłania sygnału się nie powiodła.';
	$lang['strallobjects'] = 'Wszystkie obiekty';
	$lang['strdatabasealtered'] = 'Baza danych została zmieniona.';
	$lang['strdatabasealteredbad'] = 'Próba modyfikacji bazy danych się nie powiodła.';

	// Views
	$lang['strview'] = 'Widok';
	$lang['strviews'] = 'Widoki';
	$lang['strshowallviews'] = 'Pokaż wszystkie widoki';
	$lang['strnoview'] = 'Nie znaleziono widoku.';
	$lang['strnoviews'] = 'Nie znaleziono widoków.';
	$lang['strcreateview'] = 'Utwórz widok';
	$lang['strviewname'] = 'Nazwa widoku';
	$lang['strviewneedsname'] = 'Musisz nazwać widok.';
	$lang['strviewneedsdef'] = 'Musisz zdefiniować widok.';
	$lang['strviewneedsfields'] = 'Musisz podać kolumny, które mają być widoczne w widoku.';
	$lang['strviewcreated'] = 'Widok został utworzony.';
	$lang['strviewcreatedbad'] = 'Próba utworzenia widoku się nie powiodła.';
	$lang['strconfdropview'] = 'Czy na pewno chcesz usunąć widok "%s"?';
	$lang['strviewdropped'] = 'Widok został usunięty.';
	$lang['strviewdroppedbad'] = 'Próba usunięcia widoku się nie powiodła.';
	$lang['strviewupdated'] = 'Widok został zaktualizowany.';
	$lang['strviewupdatedbad'] = 'Próba aktualizacji widoku się nie powiodła.';
	$lang['strviewlink'] = 'Klucze łączące';
	$lang['strviewconditions'] = 'Dodatkowe warunki';
	$lang['strcreateviewwiz'] = 'Utwórz widok przy użyciu kreatora widoków';

	// Sequences
	$lang['strsequence'] = 'Sekwencja';
	$lang['strsequences'] = 'Sekwencje';
	$lang['strshowallsequences'] = 'Pokaż wszystkie sekwencje';
	$lang['strnosequence'] = 'Nie znaleziono sekwencji.';
	$lang['strnosequences'] = 'Nie znaleziono sekwencji.';
	$lang['strcreatesequence'] = 'Utwórz sekwencję';
	$lang['strlastvalue'] = 'Ostatnia wartość';
	$lang['strincrementby'] = 'Zwiększana o';	
	$lang['strstartvalue'] = 'Wartość początkowa';
	$lang['strmaxvalue'] = 'Wartość maks.';
	$lang['strminvalue'] = 'Wartość min.';
	$lang['strcachevalue'] = 'Wartość keszowana';
	$lang['strlogcount'] = 'log_cnt';
	$lang['striscycled'] = 'czy cykliczna';
	$lang['strsequenceneedsname'] = 'Musisz nazwać sekwencję.';
	$lang['strsequencecreated'] = 'Sekwencja została utworzona.';
	$lang['strsequencecreatedbad'] = 'Próba utworzenia sekwencji się nie powiodła.';
	$lang['strconfdropsequence'] = 'Czy na pewno chcesz usunąć sekwencję "%s"?';
	$lang['strsequencedropped'] = 'Sekwencja została usunięta.';
	$lang['strsequencedroppedbad'] = 'Próba usunięcia sekwencji się nie powiodła.';
	$lang['strsequencereset'] = 'Sekwencja została wyzerowana.';
	$lang['strsequenceresetbad'] = 'Próba zerowania sekwencji się nie powiodła.';
 	$lang['straltersequence']  =  'Zmień sekwencję';
 	$lang['strsequencealtered']  =  'Sekwencja została zmieniona.';
 	$lang['strsequencealteredbad']  =  'Próba modyfikacji sekwencji się nie powiodła.';
 	$lang['strsetval']  =  'Ustaw wartość';
 	$lang['strsequencesetval']  =  'Wartość sekwencji została ustawiona.';
 	$lang['strsequencesetvalbad']  =  'Próba ustawienia wartości sekwencji się nie powiodła.';
 	$lang['strnextval']  =  'Zwiększ wartość sekwencję';
 	$lang['strsequencenextval']  =  'Wartość sekwencji została zwiększona.';
 	$lang['strsequencenextvalbad']  =  'Próba zwiększenia wartości sekwencji się nie powiodła.';

	// Indeksy
	$lang['strindex'] = 'Indeks';
	$lang['strindexes'] = 'Indeksy';
	$lang['strindexname'] = 'Nazwa indeksu';
	$lang['strshowallindexes'] = 'Pokaż wszystkie indeksy';
	$lang['strnoindex'] = 'Nie znaleziono indeksu.';
	$lang['strnoindexes'] = 'Nie znaleziono indeksów.';
	$lang['strcreateindex'] = 'Utwórz indeks';
	$lang['strtabname'] = 'Tab Name';
	$lang['strcolumnname'] = 'Nazwa kolumny';
	$lang['strindexneedsname'] = 'Musisz nazwać indeks.';
	$lang['strindexneedscols'] = 'W skład indeksu musi wchodzić przynajmniej jedna kolumna.';
	$lang['strindexcreated'] = 'Indeks został utworzony.';
	$lang['strindexcreatedbad'] = 'Próba utworzenia indeksu się nie powiodła.';
	$lang['strconfdropindex'] = 'Czy na pewno chcesz usunąć indeks "%s"?';
	$lang['strindexdropped'] = 'Indeks został usunięty.';
	$lang['strindexdroppedbad'] = 'Próba usunięcia indeksu się nie powiodła.';
	$lang['strkeyname'] = 'Nazwa klucza';
	$lang['struniquekey'] = 'Klucz Unikatowy';
	$lang['strprimarykey'] = 'Klucz Główny';
	$lang['strindextype'] = 'Typ indeksu';
	$lang['strtablecolumnlist'] = 'Kolumny w tabeli';
	$lang['strindexcolumnlist'] = 'Kolumny w indeksie';
	$lang['strconfcluster'] = 'Czy na pewno chcesz zklastrować "%s"?';
	$lang['strclusteredgood'] = 'Klastrowanie zostało zakończone.';
	$lang['strclusteredbad'] = 'Próba klastrowania się nie powiodła.';
	$lang['strcluster'] = 'Klaster';

	// Rules
	$lang['strrules'] = 'Reguły';
	$lang['strrule'] = 'Reguła';
	$lang['strshowallrules'] = 'Pokaż wszystkie reguły';
	$lang['strnorule'] = 'Nie znaleziono reguły.';
	$lang['strnorules'] = 'Nie znaleziono reguł.';
	$lang['strcreaterule'] = 'Utwórz regułę';
	$lang['strrulename'] = 'Nazwa reguły';
	$lang['strruleneedsname'] = 'Musisz nazwać regułę.';
	$lang['strrulecreated'] = 'Reguła została utworzona.';
	$lang['strrulecreatedbad'] = 'Próba utworzenia reguły się nie powiodła.';
	$lang['strconfdroprule'] = 'Czy na pewno chcesz usunąć regułę "%s" na "%s"?';
	$lang['strruledropped'] = 'Reguła została usunięta.';
	$lang['strruledroppedbad'] = 'Próba usunięcia reguły się nie powiodła.';

	// Constraints
	$lang['strconstraint'] = 'Więz integralności';
	$lang['strconstraints'] = 'Więzy integralności';
	$lang['strshowallconstraints'] = 'Pokaż wszystkie więzy integralności';
	$lang['strnoconstraints'] = 'Nie znaleziono więzów integralności.';
	$lang['strcreateconstraint'] = 'Utwórz więzy integralności';
	$lang['strconstraintcreated'] = 'Więzy integralności zostały utworzone.';
	$lang['strconstraintcreatedbad'] = 'Próba utworzenia więzów integralności się nie powiodła.';
	$lang['strconfdropconstraint'] = 'Czy na pewno chcesz usunąć więzy integralności "%s" na "%s"?';
	$lang['strconstraintdropped'] = 'Więzy integralności zostały usunięte.';
	$lang['strconstraintdroppedbad'] = 'Próba usunięcia więzów integralności się nie powiodła.';
	$lang['straddcheck'] = 'Dodaj warunek';
	$lang['strcheckneedsdefinition'] = 'Musisz zdefiniować warunek.';
	$lang['strcheckadded'] = 'Warunek został dodany.';
	$lang['strcheckaddedbad'] = 'Próba dodania warunku się nie powiodła.';
	$lang['straddpk'] = 'Dodaj klucz główny';
	$lang['strpkneedscols'] = 'Klucz główny musi zawierać przynajmniej jedną kolumnę.';
	$lang['strpkadded'] = 'Klucz główny został dodany.';
	$lang['strpkaddedbad'] = 'Próba dodania klucza głównego się nie powiodła.';
	$lang['stradduniq'] = 'Dodaj klucz unikatowy';
	$lang['struniqneedscols'] = 'Klucz unikatowy musi zawierać przynajmniej jedną kolumnę.';
	$lang['struniqadded'] = 'Klucz unikatowy został dodany.';
	$lang['struniqaddedbad'] = 'Próba dodania klucza unikatowego się nie powiodła.';
	$lang['straddfk'] = 'Dodaj klucz obcy';
	$lang['strfkneedscols'] = 'Obcy klucz musi zawierać przynajmniej jedną kolumnę.';
	$lang['strfkneedstarget'] = 'Klucz obcy wymaga podania nazwy tabeli docelowej.';
	$lang['strfkadded'] = 'Klucz obcy został dodany.';
	$lang['strfkaddedbad'] = 'Próba dodania klucza obcego się nie powiodła.';
	$lang['strfktarget'] = 'Tabela docelowa';
	$lang['strfkcolumnlist'] = 'Kolumna w kluczu';
	$lang['strondelete'] = 'ON DELETE';
	$lang['stronupdate'] = 'ON UPDATE';

	// Functions
	$lang['strfunction'] = 'Funkcja';
	$lang['strfunctions'] = 'Funkcje';
	$lang['strshowallfunctions'] = 'Pokaż wszystkie funkcje';
	$lang['strnofunction'] = 'Nie znaleziono funkcji.';
	$lang['strnofunctions'] = 'Nie znaleziono funkcji.';
	$lang['strcreateplfunction'] = 'Utwórz funkcję SQL/PL';
	$lang['strcreateinternalfunction'] = 'Utwórz funkcję wewnętrzną';
	$lang['strcreatecfunction'] = 'Utwórz funkcję C';
	$lang['strfunctionname'] = 'Nazwa funkcji';
	$lang['strreturns'] = 'Zwraca';
	$lang['strproglanguage'] = 'Język';
	$lang['strfunctionneedsname'] = 'Musisz nazwać funkcję.';
	$lang['strfunctionneedsdef'] = 'Musisz zdefiniować funkcję.';
	$lang['strfunctioncreated'] = 'Funkcja została utworzona.';
	$lang['strfunctioncreatedbad'] = 'Próba utworzenia funkcji się nie powiodła.';
	$lang['strconfdropfunction'] = 'Czy na pewno chcesz usunąć funkcję "%s"?';
	$lang['strfunctiondropped'] = 'Funkcja została usunięta.';
	$lang['strfunctiondroppedbad'] = 'Próba usunięcia funkcji się nie powiodła.';
	$lang['strfunctionupdated'] = 'Funkcja została zaktualizowana.';
	$lang['strfunctionupdatedbad'] = 'Próba aktualizacji funkcji się nie powiodła.';
  $lang['strobjectfile'] = 'Plik obiektów';
  $lang['strlinksymbol'] = 'Łącz symbol';
	$lang['strarguments']  =  'Argumenty';
	$lang['strargname']  =  'Nazwa';
	$lang['strargmode']  =  'Tryb';
	$lang['strargtype']  =  'Typ';
	$lang['strargadd']  =  'Dodaj nowy argument';
	$lang['strargremove']  =  'Usuń ten argument';
	$lang['strargnoargs']  =  'Ta funkcja nie będzie wymagała żadnych argumentów.';
	$lang['strargenableargs']  =  'Włącz podawanie argumentów tej funkcji.';
	$lang['strargnorowabove']  =  'Nad tym wierszem musi być wiersz.';
	$lang['strargnorowbelow']  =  'Pod tym wierszem musi być inny wiersz.';
	$lang['strargraise']  =  'Przesuń w górę.';
	$lang['strarglower']  =  'Przesuń w dół.';
	$lang['strargremoveconfirm']  =  'Czy na pewno chcesz usunąć ten argument? Tej operacji nie będzie można cofnąć.';


	// Triggers
	$lang['strtrigger'] = 'Procedura wyzwalana';
	$lang['strtriggers'] = 'Procedury wyzwalane';
	$lang['strshowalltriggers'] = 'Pokaż wszystkie procedury wyzwalane';
	$lang['strnotrigger'] = 'Nie znaleziono procedury wyzwalanej.';
	$lang['strnotriggers'] = 'Nie znaleziono procedur wyzwalanych.';
	$lang['strcreatetrigger'] = 'Utwórz procedurę wyzwalaną';
	$lang['strtriggerneedsname'] = 'Musisz nazwać procedurę wyzwalaną.';
	$lang['strtriggerneedsfunc'] = 'Musisz podać funkcję procedury wyzwalanej.';
	$lang['strtriggercreated'] = 'Procedura wyzwalana została utworzona.';
	$lang['strtriggercreatedbad'] = 'Próba utworzenia procedury wyzwalanej się nie powiodła.';
	$lang['strconfdroptrigger'] = 'Czy na pewno chcesz usunąć procedurę "%s" wyzwalaną przez "%s"?';
	$lang['strconfenabletrigger']  =  'Czy na pewno chcesz włączyć procedurę wyzwalaną "%s" on "%s"?';
	$lang['strconfdisabletrigger']  =  'Czy na pewno chcesz wyłączyć procedurę wyzwalaną "%s" on "%s"?';
	$lang['strtriggerdropped'] = 'Procedura wyzwalana została usunięta.';
	$lang['strtriggerdroppedbad'] = 'Próba usunięcia procedury wyzwalanej się nie powiodła.';
	$lang['strtriggerenabled']  =  'Procedura wyzwalana została włączona.';
	$lang['strtriggerenabledbad']  =  'Próba włączenia procedury wyzwalanej się nie powiodła.';
	$lang['strtriggerdisabled']  =  'Procedura wyzwalana została wyłączona.';
	$lang['strtriggerdisabledbad']  =  'Próba wyłączenia procedury wyzwalanej się nie powiodła.';
	$lang['strtriggeraltered'] = 'Procedura wyzwalana została zmieniona.';
	$lang['strtriggeralteredbad'] = 'Próba modyfikacji procedury wyzwalanej się nie powiodła.';
	$lang['strforeach'] = 'Dla wszystkich';

	// Types
	$lang['strtype'] = 'Typ';
	$lang['strtypes'] = 'Typy';
	$lang['strshowalltypes'] = 'Pokaż wszystkie typy';
	$lang['strnotype'] = 'Nie znaleziono typu.';
	$lang['strnotypes'] = 'Nie znaleziono typów.';
	$lang['strcreatetype'] = 'Utwórz typ';
	$lang['strcreatecomptype'] = 'Utwórz typ złożony';
	$lang['strtypeneedsfield'] = 'Musisz podać przynajmniej jedno pole.';
	$lang['strtypeneedscols'] = 'Musisz podać poprawną ilość pól.';	
	$lang['strtypename'] = 'Nazwa typu';
	$lang['strinputfn'] = 'Funkcja wejściowa';
	$lang['stroutputfn'] = 'Funkcja wyjściowa';
	$lang['strpassbyval'] = 'Przekazywany przez wartość?';
	$lang['stralignment'] = 'Wyrównanie bajtowe';
	$lang['strelement'] = 'Typ elementów';
	$lang['strdelimiter'] = 'Znak oddzielający elementy tabeli';
	$lang['strstorage'] = 'Technika przechowywania';
	$lang['strfield'] = 'Pole';
	$lang['strnumfields'] = 'Ilość pól';
	$lang['strtypeneedsname'] = 'Musisz nazwać typ.';
	$lang['strtypeneedslen'] = 'Musisz podać długość typu.';
	$lang['strtypecreated'] = 'Typ został utworzony.';
	$lang['strtypecreatedbad'] = 'Próba utworzenia typu się nie powiodła.';
	$lang['strconfdroptype'] = 'Czy na pewno chcesz usunąć typ "%s"?';
	$lang['strtypedropped'] = 'Typ został usunięty.';
	$lang['strtypedroppedbad'] = 'Próba usunięcia typu się nie powiodła.';
  $lang['strflavor'] = 'Flavor';
	$lang['strbasetype'] = 'podstawowy';
	$lang['strcompositetype'] = 'złożony';
	$lang['strpseudotype'] = 'pseudo';

	// Schemas
	$lang['strschema'] = 'Schemat';
	$lang['strschemas'] = 'Schematy';
	$lang['strshowallschemas'] = 'Pokaż wszystkie schematy';
	$lang['strnoschema'] = 'Nie znaleziono schematu.';
	$lang['strnoschemas'] = 'Nie znaleziono schematów.';
	$lang['strcreateschema'] = 'Utwórz schemat';
	$lang['strschemaname'] = 'Nazwa schematu';
	$lang['strschemaneedsname'] = 'Musisz nadać schematowi nazwę.';
	$lang['strschemacreated'] = 'Schemat został utworzony.';
	$lang['strschemacreatedbad'] = 'Próba utworzenia schematu się nie powiodła.';
	$lang['strconfdropschema'] = 'Czy na pewno chcesz usunąć schemat "%s"?';
	$lang['strschemadropped'] = 'Schemat został usunięty.';
	$lang['strschemadroppedbad'] = 'Próba usunięcia schematu się nie powiodła.';
	$lang['strschemaaltered'] = 'Schemat został zmieniony.';
	$lang['strschemaalteredbad'] = 'Próba zmiany schematu się nie powiodła.';
	$lang['strsearchpath'] = 'Ścieżka wyszukiwania schematu';

	// Reports

	// Domeny
	$lang['strdomain'] = 'Domena';
	$lang['strdomains'] = 'Domeny';
	$lang['strshowalldomains'] = 'Pokaż wszystkie domeny';
	$lang['strnodomains'] = 'Nie znaleziono domen.';
	$lang['strcreatedomain'] = 'Utwórz domenę';
	$lang['strdomaindropped'] = 'Domena została usunięta.';
	$lang['strdomaindroppedbad'] = 'Próba usunięcia domeny się nie powiodła.';
	$lang['strconfdropdomain'] = 'Czy na pewno chcesz usunąć domenę "%s"?';
	$lang['strdomainneedsname'] = 'Musisz nazwać domenę.';
	$lang['strdomaincreated'] = 'Domena została utworzona.';
	$lang['strdomaincreatedbad'] = 'Próba utworzenia domeny się nie powiodła.';
	$lang['strdomainaltered'] = 'Domena została zmieniona.';
	$lang['strdomainalteredbad'] = 'Próba modyfikacji domeny się nie powiodła.';

	// Operators
	$lang['stroperator'] = 'Operator';
	$lang['stroperators'] = 'Operatory';
	$lang['strshowalloperators'] = 'Pokaż wszystkie operatory';
	$lang['strnooperator'] = 'Nie znaleziono operatora.';
	$lang['strnooperators'] = 'Nie znaleziono operatorów.';
	$lang['strcreateoperator'] = 'Utwórz operator';
	$lang['strleftarg'] = 'Typ lewego argumentu';
	$lang['strrightarg'] = 'Typ prawego argumentu';
	$lang['strcommutator'] = 'Komutator';
	$lang['strnegator'] = 'Negacja';
	$lang['strrestrict'] = 'Zastrzeżenie';
	$lang['strjoin'] = 'Połączenie';
  $lang['strhashes'] = 'Hashes';
  $lang['strmerges'] = 'Merges';
	$lang['strleftsort'] = 'Lewe sortowanie';
	$lang['strrightsort'] = 'Prawe sortowanie';
	$lang['strlessthan'] = 'Mniej niż';
	$lang['strgreaterthan'] = 'Więcej niż';
	$lang['stroperatorneedsname'] = 'Musisz nazwać operator.';
	$lang['stroperatorcreated'] = 'Operator został utworzony.';
	$lang['stroperatorcreatedbad'] = 'Próba utworzenia operatora się nie powiodła.';
	$lang['strconfdropoperator'] = 'Czy na pewno chcesz usunąć operator "%s"?';
	$lang['stroperatordropped'] = 'Operator został usunięty.';
	$lang['stroperatordroppedbad'] = 'Próba usunięcia operatora się nie powiodła.';

	// Casts
	$lang['strcasts'] = 'Rzutowania';
	$lang['strnocasts'] = 'Nie znaleziono rzutowań.';
	$lang['strsourcetype'] = 'Typ źródłowy';
	$lang['strtargettype'] = 'Typ docelowy';
	$lang['strimplicit'] = 'Domniemany';
	$lang['strinassignment'] = 'W przydziale';
	$lang['strbinarycompat'] = '(Kompatybilny binarnie)';
	
	// Conversions
	$lang['strconversions'] = 'Konwersje';
	$lang['strnoconversions'] = 'Nie znaleziono konwersji.';
	$lang['strsourceencoding'] = 'Kodowanie źródłowe';
	$lang['strtargetencoding'] = 'Kodowanie docelowe';
	
	// Languages
	$lang['strlanguages'] = 'Języki';
	$lang['strnolanguages'] = 'Nie znaleziono języków.';
	$lang['strtrusted'] = 'Zaufany';
	
	// Info
	$lang['strnoinfo'] = 'Brak informacji na ten temat';
	$lang['strreferringtables'] = 'Tabele zależne';
	$lang['strparenttables'] = 'Tabela nadrzędne';
	$lang['strchildtables'] = 'Tabela podrzędna';
	
	// Aggregates
	$lang['straggregate']  = 'Funkcja agregująca';
	$lang['straggregates'] = 'Funkcje agregujące';
	$lang['strnoaggregates'] = 'Nie znaleziono funkcji agregujących.';
	$lang['stralltypes'] = '(Wszystkie typy)';
$lang['straggrtransfn']  =  'Transition function';
	$lang['strcreateaggregate']  =  'Utwórz funkcję agregującą';
	$lang['straggrbasetype']  =  'Typ danych wejściowych';
$lang['straggrsfunc']  =  'State transition function';
$lang['straggrffunc']  =  'Final function';
	$lang['straggrinitcond']  =  'Warunek początkowy';
	$lang['straggrsortop']  =  'Operator sortowania';
	$lang['strconfdropaggregate']  =  'Czy na pewno chcesz usunąć funkcję agregującą "%s"?';
	$lang['straggregatedropped']  =  'Funkcja agregująca została usunięta.';
	$lang['straggregatedroppedbad']  =  'Próba usunięcia funkcji agregującej się nie powiodła.';
	$lang['stralteraggregate']  =  'Zmień funkcję agregującą';
	$lang['straggraltered']  =  'Funkcja agregująca została zmieniona.';
	$lang['straggralteredbad']  =  'Próba zmiany funkcji agregującej się nie powiodła.';
	$lang['straggrneedsname']  =  'Musisz podać nazwę funkcji agregującej';
	$lang['straggrneedsbasetype']  =  'Musisz podać typ danych wejściowych funkcji agregującej';
$lang['straggrneedssfunc']  =  'You must specify the name of the state transition function for the aggregate';
$lang['straggrneedsstype']  =  'You must specify the data type for the aggregate\'s state value';
	$lang['straggrcreated']  =  'Funkcja agregująca została utworzona.';
	$lang['straggrcreatedbad']  =  'Próba utworzenia funkcji agregującej się nie powiodła.';
	$lang['straggrshowall']  =  'Pokaż wszystkie funkcje agregujące';

	// Operator Classes
	$lang['stropclasses'] = 'Klasy operatorów';
	$lang['strnoopclasses'] = 'Nie znaleziono klas operatorów.';
	$lang['straccessmethod'] = 'Metoda dostępu';

	// Stats and performance
	$lang['strrowperf'] = 'Wydajność wierszowa';
	$lang['strioperf'] = 'Wydajność I/O';
	$lang['stridxrowperf'] = 'Wydajność indeksu wierszowego';
	$lang['stridxioperf'] = 'Wydajność indeksu We/Wy';
	$lang['strpercent'] = '%';
	$lang['strsequential'] = 'Sekwencyjny';
	$lang['strscan'] = 'Skanuj';
	$lang['strread'] = 'Czytaj';
	$lang['strfetch'] = 'Pobierz';
	$lang['strheap'] = 'Sterta';
	$lang['strtoast'] = 'TOAST';
	$lang['strtoastindex'] = 'Indeks TOAST';
	$lang['strcache'] = 'Kesz';
	$lang['strdisk'] = 'Dysk';
	$lang['strrows2'] = 'Wiersze';

	// Tablespaces
	$lang['strtablespace'] = 'Przestrzeń tabel';
	$lang['strtablespaces'] = 'Przestrzenie tabel';
	$lang['strshowalltablespaces'] = 'Pokaż wszystkie przestrzenie tabel';
	$lang['strnotablespaces'] = 'Nie znaleziono przestrzeni tabel.';
	$lang['strcreatetablespace'] = 'Utwórz przestrzeń tabel';
	$lang['strlocation'] = 'Położenie';
	$lang['strtablespaceneedsname'] = 'Musisz podać nazwę przestrzeni tabel.';
	$lang['strtablespaceneedsloc'] = 'Musisz podać nazwę katalogu, w którym chcesz utworzyć przestrzeń tabel.';
	$lang['strtablespacecreated'] = 'Przestrzeń tabel została utworzona.';
	$lang['strtablespacecreatedbad'] = 'Próba utworzenia przestrzeni tabel się nie powiodła.';
	$lang['strconfdroptablespace'] = 'Czy na pewno chcesz usunąć przestrzeń tabel "%s"?';
	$lang['strtablespacedropped'] = 'Przestrzeń tabel została usunięta.';
	$lang['strtablespacedroppedbad'] = 'Próba usunięcia przestrzeni tabel się nie powiodła.';
	$lang['strtablespacealtered'] = 'Przestrzeń tabel została zmieniona.';
	$lang['strtablespacealteredbad'] = 'Próba modyfikacji przestrzeni tabel się nie powiodła.';


	// Miscellaneous
	$lang['strtopbar'] = '%s uruchomiony na %s:%s -- Jesteś zalogowany jako "%s"';
	$lang['strtimefmt'] = 'jS M, Y g:iA';
	$lang['strhelp'] = 'Pomoc';
	$lang['strhelpicon'] = '?';
	$lang['strlogintitle'] = 'Zaloguj do %s';
	$lang['strlogoutmsg'] = 'Wylogowano z %s';
	$lang['strloading'] = 'Ładuję...';
	$lang['strerrorloading'] = 'Błąd ładowania';
	$lang['strclicktoreload'] = 'Kliknij aby odświeżyć';

	//Autovacuum
	$lang['strautovacuum'] = 'Czyszczenie automatyczne'; 
	$lang['strturnedon']  =  'Włączone'; 
	$lang['strturnedoff']  =  'Wyłączone'; 
	$lang['strenabled'] = 'Aktywne'; 
	$lang['strvacuumbasethreshold'] = 'Podstawowy próg czyszczenia'; 
	$lang['strvacuumscalefactor'] = 'Współczynnik czyszczenia'; 
	$lang['stranalybasethreshold'] = 'Podstawowy próg analizy'; 
	$lang['stranalyzescalefactor'] = 'Współczynnik analizy'; 
	$lang['strvacuumcostdelay'] = 'Opóźnienie po przekroczeniu kosztu czyszczenia'; 
	$lang['strvacuumcostlimit'] = 'Limit kosztu czyszczenia'; 

        //Table-level Locks
	$lang['strlocks']  =  'Blokady';
	$lang['strtransaction']  =  'ID transakcji';
	$lang['strprocessid']  =  'ID procesu';
	$lang['strmode']  =  'Tryb blokowania';
	$lang['strislockheld']  =  'Czy blokada obowiązuje?';

	// Prepared transactions
	$lang['strpreparedxacts']  =  'Przygotowane transakcje';
	$lang['strxactid']  =  'ID transakcji';
	$lang['strgid']  =  'Globalny ID';
?>
