<?php
	/**
	 * German language file.
	 */

	//Basic
	$plugin_lang['strplugindescription'] = 'Report plugin';
	$plugin_lang['strnoreportsdb'] = 'Sie haben die Berichtsdatenbank nicht angelegt. In der Datei INSTALL finden Sie Anweisungen dafür.';

	// Reports
	$plugin_lang['strreport'] = 'Bericht';
	$plugin_lang['strreports'] = 'Berichte';
	$plugin_lang['strshowallreports'] = 'Alle Berichte anzeigen';
	$plugin_lang['strnoreports'] = 'Keine Berichte gefunden.';
	$plugin_lang['strcreatereport'] = 'Bericht erstellen.';
	$plugin_lang['strreportdropped'] = 'Bericht gelöscht.';
	$plugin_lang['strreportdroppedbad'] = 'Löschen des Berichtes fehlgeschlagen.';
	$plugin_lang['strconfdropreport'] = 'Sind Sie sicher, dass Sie den Bericht "%s" löschen wollen?';
	$plugin_lang['strreportneedsname'] = 'Sie müssen für den Bericht einen Namen angeben.';
	$plugin_lang['strreportneedsdef'] = 'Sie müssen eine SQL-Abfrage für den Bericht eingeben.';
	$plugin_lang['strreportcreated'] = 'Bericht gespeichert.';
	$plugin_lang['strreportcreatedbad'] = 'Speichern des Berichtes fehlgeschlagen.';
?>
