@import url(../global.css);
/**
 * cappuccino style sheet
 */
/* ELEMENTS */
body {
	background-color: #ded9c9;
	margin:	0;
	padding: 0;
	font-family: arial;
	font-size: 0.9em; /*0.8em;*/
}
body > * { margin-left: 20px }
body.browser {
	background-color: #363330;
	font-size: 0.9em;
	border-right: 1px dashed #887f5c;
	color: #fff;
}
body.browser > * { margin: 0 }
body.browser div.webfx-tree-row:hover { background: #524a42}
h1 {font-size: 1.5em}
h2 {
	color: #fff;
	font-size: 1em;
	font-weight: bold;
	border: 2px solid #363330;
	background-color: #363330;
	padding: 2px 1em;
	margin-top: 2em;
	margin-bottom: 2em;
}
h3 {
	color: #111;
	font-weight: bold;
}
table {
	border: 0;
	border-collapse: collapse;
}
td, th {
	padding: 1px 8px;
}
a {
	color: #2d547b;
	text-decoration: none;
}
a:hover {
	color: #cc0000;
	text-decoration: underline;
}
input[type=checkbox], input[type=password], input[type=text], input[type=radio] {
	background: #ded4b3;
	border: 1px solid #887f5c;
}
input[type=submit], input[type=reset], input[type=button], select {
	background: #c4ba95 url('../../images/themes/cappuccino/inputbckg.png') repeat-x top left;
	border: 1px solid #887f5c;
}
table.error {
	background-color: #dec9d0;
	border: 2px solid #de7c9c;
	margin: auto;
}
th.data {
	color: #fff;
	background-color: #363330;
	border: 1px dotted #887f5c;
	font-size: 0.9em;
	padding: 3px 7px;
}
th.required {text-decoration: underline}
.topbar, .trail {
	color: #fff;
	background-color: #363330;
	margin: 0;
	padding: 0;
	text-align: left;
}
.topbar a, .trail a, body.browser a, th.data a {
	color: #a8aac2;
}
.topbar .platform, .topbar .host, .topbar .username {
	font-weight: bold;
}
.topbar, .trail, .tab {
	padding: 2px 1ex;
}
.trail td {padding: 2px}
.crumb .icon {margin-right: 5px}
table.tabs {
	width: 100%;
	border-collapse: collapse;
	margin: 20px 0 40px 0;
}
.tab {
	text-align: center;
	vertical-align: top;
	font-size: 0.8em;
	border: 1px solid #887f5c;
	background-color: #c8c0a2;
	padding: 2px 10px;
	white-space: nowrap;
}
.tab:hover {background-color: #b7af8d}
.tabs .active {
	border-bottom: none;
	background-color: #ded9c9;
}
.tab .icon {
	display: block;
}
.active a {font-weight: bold}
a:hover {text-decoration: underline}
ul.toplink, ul.navlink {
	list-style: none;
	margin:0;padding:0;
}
ul.navlink{margin:20px 0 20px 20px}
ul.toplink li, ul.navlink li {
	display:inline;
	border-left:1px solid #000000;
	margin:0;padding: 0 2px 0 5px;
}
ul.toplink li:first-child, ul.navlink li:first-child {
	border: none;
	padding-left:0;
}
tr.data1, tr.data2, tr.data3 {
	color: #000000;
	font-size: 0.8em;
	border: 1px dotted #887f5c;
}
tr.data1:hover, tr.data2:hover, tr.data3:hover {
	background-color: #c8c0a2;
}
.row1, .data1 {
	background-color: #d8d2b9;
	text-align: left;
}
.row2, .data2 {
	background-color: #ded9c9;
	text-align: left;
}
.row3, .data3 {background-color: #d4c8a1}
td.opbutton1, td.opbutton2 {
	color: #000000;
	cursor:	pointer;
	padding: 2px 6px;
	text-align: center;
	border: 1px dotted #887f5c;
}
td.opbutton1:hover, td.opbutton2:hover {
	background-color: #b7af8d;
}
a.help {
	color: #A46600;
	vertical-align: super;
	text-decoration: none;
	font-size: 0.8em;
}
pre {font-size: 110%}
pre.data {font-size: 100%}
pre.error {font-size: 120%}

.intro li {font-weight: bold}
.ac_field {
	border:1px solid #363330;
	background: url('../../images/themes/cappuccino/openListe.png') no-repeat right;
	padding-right: 20px;
}
.bottom_link {
	background: #b7af8d;
	border-top: 1px dotted #887f5c;
	border-left: 1px dotted #887f5c;
}

/** FK browsing **/
div.fk {
    background: #fff;
	border-left: 1px dotted #000;
	padding: 5px;
}
div.logo {
	margin:	0px;
	padding: 0px;
	border: none;
	margin-bottom: 15px;
	background-image: url('../../images/themes/cappuccino/title.png');
	background-repeat: no-repeat;
	height: 50px;
}
div.logo a {
	display: block;
	height: 100%;
	color: transparent;
}
