<?php
	/**
	 * Hebrew language file.
	 */

	//Basic
	$plugin_lang['strplugindescription'] = 'Report plugin';
	$plugin_lang['strnoreportsdb'] = 'לא יצרתה בסיס נתונים בישביל הדוחות. אנא קרא את קובץ ה INSTALL בישביל הדרכה.';

	// Reports
	$plugin_lang['strreport'] = 'דוח';
	$plugin_lang['strreports'] = 'דוחות';
	$plugin_lang['strshowallreports'] = 'הראה את כל הדוחות';
	$plugin_lang['strnoreports'] = 'לא נמצאו דוחות.';
	$plugin_lang['strcreatereport'] = 'צור דוח';
	$plugin_lang['strreportdropped'] = 'דוח נמחק.';
	$plugin_lang['strreportdroppedbad'] = 'מחיקת דוח נכשלה';
	$plugin_lang['strconfdropreport'] = 'האם אתה בטוח שברצונך למחוק את הדוח &quot;%s&quotl?';
	$plugin_lang['strreportneedsname'] = 'אתה חייב לציין שם לדוח.';
	$plugin_lang['strreportneedsdef'] = 'אתה חייב לתת SQL לדוח.';
	$plugin_lang['strreportcreated'] = 'דוח נשמר.';
	$plugin_lang['strreportcreatedbad'] = 'שמירת דוח נכשלה.';
?>
