<?php
	/**
	 * Danish language file.
	 */

	//Basic
	$plugin_lang['strplugindescription'] = 'Report plugin';
	$plugin_lang['strnoreportsdb'] = 'Du har ikke oprettet nogen rapportdatabase. For instruktioner læs filen INSTALL.';

	// Reports
	$plugin_lang['strreport'] = 'Rapport';
	$plugin_lang['strreports'] = 'Rapporter';
	$plugin_lang['strshowallreports'] = 'Vis alle rapporter';
	$plugin_lang['strtopbar'] = '%s kører på %s:%s -- Du er logged ind som bruger "%s"';
	$plugin_lang['strtimefmt'] = 'jS M, Y g:iA';
	$plugin_lang['strnoreports'] = 'Ingen rapporter fundet.';
	$plugin_lang['strcreatereport'] = 'Opret rapport';
	$plugin_lang['strreportdropped'] = 'Rapport fjernet.';
	$plugin_lang['strreportcreated'] = 'Rapport oprettet.';
	$plugin_lang['strreportneedsname'] = 'Rapport skal have et navn.';
	$plugin_lang['strreportcreatedbad'] = 'Det lykkedes ikke at oprette rapport.';
	$plugin_lang['strreportdroppedbad'] = 'Det lykkedes ikke at fjerne rapport.';
	$plugin_lang['strconfdropreport'] = 'Er du sikker på, at du vil fjerne rapporten "%s"?';
	$plugin_lang['strreportneedsdef'] = 'Du skal angive en SQL-forespørgsel.';
?>
