<?php

/* Romanian - by "bogdan stefan" <sbogdan#rsb.ro> */

$ADODB_LANG_ARRAY = array (
			'LANG'                      => 'ro',
            DB_ERROR                    => 'eroare necunoscuta',
            DB_ERROR_ALREADY_EXISTS     => 'deja exista',
            DB_ERROR_CANNOT_CREATE      => 'nu se poate creea',
            DB_ERROR_CANNOT_DELETE      => 'nu se poate sterge',
            DB_ERROR_CANNOT_DROP        => 'nu se poate executa drop',
            DB_ERROR_CONSTRAINT         => 'violare de constrain',
            DB_ERROR_DIVZERO            => 'se divide la zero',
            DB_ERROR_INVALID            => 'invalid',
            DB_ERROR_INVALID_DATE       => 'data sau timp invalide',
            DB_ERROR_INVALID_NUMBER     => 'numar invalid',
            DB_ERROR_MISMATCH           => 'nepotrivire-mismatch',
            DB_ERROR_NODBSELECTED       => 'nu exista baza de date selectata',
            DB_ERROR_NOSUCHFIELD        => 'camp inexistent',
            DB_ERROR_NOSUCHTABLE        => 'tabela inexistenta',
            DB_ERROR_NOT_CAPABLE        => 'functie optionala neinstalata',
            DB_ERROR_NOT_FOUND          => 'negasit',
            DB_ERROR_NOT_LOCKED         => 'neblocat',
            DB_ERROR_SYNTAX             => 'eroare de sintaxa',
            DB_ERROR_UNSUPPORTED        => 'nu e suportat',
            DB_ERROR_VALUE_COUNT_ON_ROW => 'valoare prea mare pentru coloana',
            DB_ERROR_INVALID_DSN        => 'DSN invalid',
            DB_ERROR_CONNECT_FAILED     => 'conectare esuata',
            0	                       => 'fara eroare', // DB_OK
            DB_ERROR_NEED_MORE_DATA     => 'data introduse insuficiente',
            DB_ERROR_EXTENSION_NOT_FOUND=> 'extensie negasita',
            DB_ERROR_NOSUCHDB           => 'nu exista baza de date',
            DB_ERROR_ACCESS_VIOLATION   => 'permisiuni insuficiente'
);
?>