<?php

// Contributed by Grzegorz Pacan <gp#dione.cc>

$ADODB_LANG_ARRAY = array (
			'LANG'                      => 'pl',
            DB_ERROR                    => 'niezidentyfikowany błąd',
            DB_ERROR_ALREADY_EXISTS     => 'już istnieją',
            DB_ERROR_CANNOT_CREATE      => 'nie można stworzyć',
            DB_ERROR_CANNOT_DELETE      => 'nie można usunąć',
            DB_ERROR_CANNOT_DROP        => 'nie można porzucić',
            DB_ERROR_CONSTRAINT         => 'pogwałcenie uprawnień',
            DB_ERROR_DIVZERO            => 'dzielenie przez zero',
            DB_ERROR_INVALID            => 'błędny',
            DB_ERROR_INVALID_DATE       => 'błędna godzina lub data',
            DB_ERROR_INVALID_NUMBER     => 'błędny numer',
            DB_ERROR_MISMATCH           => 'niedopasowanie',
            DB_ERROR_NODBSELECTED       => 'baza danych nie została wybrana',
            DB_ERROR_NOSUCHFIELD        => 'nie znaleziono pola',
            DB_ERROR_NOSUCHTABLE        => 'nie znaleziono tabeli',
            DB_ERROR_NOT_CAPABLE        => 'nie zdolny',
            DB_ERROR_NOT_FOUND          => 'nie znaleziono',
            DB_ERROR_NOT_LOCKED         => 'nie zakmnięty',
            DB_ERROR_SYNTAX             => 'błąd składni',
            DB_ERROR_UNSUPPORTED        => 'nie obsługuje',
            DB_ERROR_VALUE_COUNT_ON_ROW => 'wartość liczona w szeregu',
            DB_ERROR_INVALID_DSN        => 'błędny DSN',
            DB_ERROR_CONNECT_FAILED     => 'połączenie nie zostało zrealizowane',
            0	                       => 'brak błędów', // DB_OK
            DB_ERROR_NEED_MORE_DATA     => 'niedostateczna ilość informacji',
            DB_ERROR_EXTENSION_NOT_FOUND=> 'nie znaleziono rozszerzenia',
            DB_ERROR_NOSUCHDB           => 'nie znaleziono bazy',
            DB_ERROR_ACCESS_VIOLATION   => 'niedostateczne uprawnienia'
);
?>