@import url(../global.css);
/**
 * Default style sheet
 */

/** ELEMENTS */
body {
	background-color: #FFFFFF;
	margin:	4px;
	font-family: arial, tahoma, verdana, helvetica, sans-serif, serif;
	padding: 0px;
	font-size: smaller; /*0.8em;*/
}
body.browser {
	background-color: #efefef;
	font-family: arial, tahoma, verdana, helvetica, sans-serif, serif;
	font-size: smaller; /*1em;*/
	border-right: 1px dashed #c0c0c0;
}
body.bottombar {
	background-color: #CECF9C;
	margin:	0px;
	padding: 0px;
	font-family: arial, tahoma, verdana, helvetica, sans-serif, serif;
	font-size: smaller; /*1em;*/
	text-align: left;
}
h2 {
	color: #666633;
	font-size: medium; /*1.3em;*/
	font-family: arial, tahoma, verdana, helvetica, sans-serif, serif;
	font-weight: bold;
	border: 2px solid #E6E6CC;
	background-color: #F3F3E9;
	padding: 2px 1em;
	margin: 0 0 1ex 0;
}
h3 {
	color: #666633;
	font-size: small;
	font-family: arial, tahoma, verdana, helvetica, sans-serif, serif;
	font-weight: bold;
}
table.error {background-color: #E6E6CC}
table.error td {background-color: #E6E6CC}
table.navbar {background-color: #E6E6CC}
table.navbar td {
	height:	25px;
	color: #000000;
	background-color: #F3F3E9;
	text-align: center;
	font-family: arial, tahoma, verdana, helvetica, sans-serif, serif;
	font-size: smaller; /* 0.9em */
	font-weight: bold;
}
table.navbar td.active {background-color: #E6E6CC}
th.data {
	color: #000000;
	background-color: #E6E6CC;
	font-family: arial, tahoma, verdana, helvetica, sans-serif, serif;
	font-size: smaller; /* 0.9em */
}
th.data a:active, th.data a:link, th.data a:visited, th.data a:hover {
	font-weight: bold;
}
td.dat {
	color: #ff0;
	text-align: center;
}
th.required {text-decoration: underline}
td.topbar {
	background-color: #CECF9C;
	margin:	0px	0px;
	padding: 0px;
	font-family: arial, tahoma, verdana, helvetica, sans-serif, serif;
	font-size: smaller; /*0.8em;*/
	text-align: left;
}
ul.toplink,ul.navlink {
	list-style: none;
	margin:0;padding:0;
}
ul.navlink{margin:20px 0}
ul.toplink li, ul.navlink li {
	display:inline;
	border-left:1px solid #000000;
	margin:0;padding: 0 2px 0 5px;
}
ul.toplink li:first-child, ul.navlink li:first-child {
	border: none;
	padding-left:0;
}
tr.data1, tr.data2, tr.data3 {
	color: #000000;
	font-family: arial, tahoma, verdana, helvetica, sans-serif, serif;
	font-size: smaller; /*0.8em;*/
}
tr.data1:hover, tr.data2:hover, tr.data3:hover {
	background-color: #DDD;
}
.row1, .data1 {
	background-color: #F3F3E9;
	text-align: left;
}
.row2, .data2 {
	background-color: #E6E6CC;
	text-align: left;
}
.row3, .data3 {background-color: #F3F3E9}
td.opbutton1 {
	color: #000000;
	border-top:	1px solid #FFFFFF;
	border-right: 1px solid	#706D41;
	border-bottom: 1px solid #706D41;
	border-left: 1px solid #FFFFFF;
	cursor:	pointer;
	font-family: arial, tahoma, verdana, helvetica, sans-serif, serif;
	font-size: smaller; /*0.8em;*/
	padding-left: 6px;
	padding-right: 6px;
	text-align: center;
}
td.opbutton2 {
	color: #000000;
	border-top:	1px solid #FFFFFF;
	border-right: 1px solid	#706D41;
	border-bottom: 1px solid #706D41;
	border-left: 1px solid #FFFFFF;
	cursor:	pointer;
	font-family: arial, tahoma, verdana, helvetica, sans-serif, serif;
	font-size: smaller; /*0.8em;*/
	padding-left: 6px;
	padding-right: 6px;
	text-align: center;
}
.topbar {border: 2px solid #CECF9C}
.topbar, .topbar * {
	background-color: #CECF9C;
}
.topbar .platform, .topbar .host, .topbar .username {
	font-weight: bold;
}
.topbar, .trail {
	margin-bottom: 2px;
}
.topbar, .trail, .tab {
	padding: 2px 1ex;
	font-size: smaller;
}
.trail, .tab {
	border: 2px solid #E6E6CC;
	background-color: #F3F3E9;
}
.trail .crumb {background-color: #F3F3E9}
.crumb, .tab {
	vertical-align: top;
}
.crumb .icon {
	vertical-align: middle;
	margin: 0 2px;
}
table.tabs {
	width: 100%;
	border-collapse: collapse;
	margin-bottom: 1ex;
}
.tab {text-align: center}
.tabs .active {background-color: #E6E6CC}
.tab .icon {display: block}
a:active {
	color: #989973;
	font-family: arial, tahoma, verdana, helvetica, sans-serif, serif;
	font-weight: normal;
	text-decoration: underline;
}
a,a:link {
	color: #336699;
	font-family: arial, tahoma, verdana, helvetica, sans-serif, serif;
	text-decoration: none;
}
a:visited {
	color: #336699;
	font-family: arial, tahoma, verdana, helvetica, sans-serif, serif;
	text-decoration: none;
}
a:hover {
	color: #cc0000;
	font-family: arial, tahoma, verdana, helvetica, sans-serif, serif;
	text-decoration: none;
}
a.navlink:link, a.toplink:link, ul.navlink li a, ul.toplink li a {
	color: #336699;
	font-family: arial, tahoma, verdana, helvetica, sans-serif, serif;
	font-weight: bold;
	text-decoration: none;
}
a.navlink:visited, a.toplink:visited, ul.navlink li a:visited, ul.toplink li a:visited {
	color: #336699;
	font-family: arial, tahoma, verdana, helvetica, sans-serif, serif;
	font-weight: bold;
	text-decoration: none;
}
a.navlink:hover, a.toplink:hover, ul.navlink li a:hover, ul.toplink li a:hover {
	color: #cc0000;
	font-family: arial, tahoma, verdana, helvetica, sans-serif, serif;
	font-weight: bold;
	text-decoration: none;
}
a.navlink:active, a.toplink:active, ul.navlink li a:active, ul.toplink li a:active {
	color: #cc0000;
	font-family: arial, tahoma, verdana, helvetica, sans-serif, serif;
	font-weight: bold;
	text-decoration: none;
}
.active a {font-weight: bold}
a.help {
	color: #E68800;
	font-size: smaller;
	vertical-align: super;
	text-decoration: none;
}
pre {font-size: 110%}
pre.data {
	font-family: arial, tahoma, verdana, helvetica, sans-serif, serif;
	font-size: 100%;
}
pre.error {
	font-family: "Lucida Console", "Courier New", "DejaVu Sans Mono", monospace;
	font-size: 120%;
}
.intro li {font-weight: bold}
.ac_field {border:1px solid #D9D95F}
.bottom_link {
	background: #eee;
	border-top: 1px dotted #999;
	border-left: 1px dotted #999;
	font-size: smaller;
}

/** FK browsing **/
div#root > div.fk {
	border: 1px solid #000;
}
div.fk {
    background: #fff;
	border-left: 1px solid #000;
	padding: 5px;
}
div.logo {
	background-color: #CECF9C;
	margin:	0px;
	padding: 0px;
	font-family: arial, tahoma, verdana, helvetica, sans-serif, serif;
	font-size: smaller; /* 1em; */
	border: none;
	border-bottom: 2px solid #000000;
	margin-bottom: 2px;
	background-image: url('../../images/themes/default/title.png');
	background-repeat: no-repeat;
	height: 50px;
}
div.logo a {
	display: block;
	height: 100%;
	color: transparent;
}
