<?php

// Ukrainian language file contributed by  Alex Rootoff rootoff{AT}pisem.net.

$ADODB_LANG_ARRAY = array (
             'LANG'                      => 'uk1251',
            DB_ERROR                    => 'невідома помилка',
            DB_ERROR_ALREADY_EXISTS     => 'вже існує',
            DB_ERROR_CANNOT_CREATE      => 'неможливо створити',
            DB_ERROR_CANNOT_DELETE      => 'неможливо видалити',
            DB_ERROR_CANNOT_DROP        => 'неможливо знищити (drop)',
            DB_ERROR_CONSTRAINT         => 'порушення умов перевірки',
            DB_ERROR_DIVZERO            => 'ділення на 0',
            DB_ERROR_INVALID            => 'неправильно',
            DB_ERROR_INVALID_DATE       => 'неправильна дата чи час',
            DB_ERROR_INVALID_NUMBER     => 'неправильне число',
            DB_ERROR_MISMATCH           => 'помилка',
            DB_ERROR_NODBSELECTED       => 'не вибрано БД',
            DB_ERROR_NOSUCHFIELD        => 'не існує поле',
            DB_ERROR_NOSUCHTABLE        => 'не існує таблиця',
            DB_ERROR_NOT_CAPABLE        => 'СУБД не в стані',
            DB_ERROR_NOT_FOUND          => 'не знайдено',
            DB_ERROR_NOT_LOCKED         => 'не заблоковано',
            DB_ERROR_SYNTAX             => 'синтаксична помилка',
            DB_ERROR_UNSUPPORTED        => 'не підтримується',
            DB_ERROR_VALUE_COUNT_ON_ROW => 'рахівник значень в стрічці',
            DB_ERROR_INVALID_DSN        => 'неправильна DSN',
            DB_ERROR_CONNECT_FAILED     => 'з\'єднання неуспішне',
            0                               => 'все гаразд', // DB_OK
            DB_ERROR_NEED_MORE_DATA     => 'надано недостатньо даних',
            DB_ERROR_EXTENSION_NOT_FOUND=> 'розширення не знайдено',
            DB_ERROR_NOSUCHDB           => 'не існує БД',
            DB_ERROR_ACCESS_VIOLATION   => 'недостатньо прав доступа'
);
?>