<?php
	/**
	* French Language file.
	*/

	//Basic
	$plugin_lang['strplugindescription'] = 'Report plugin';
	$plugin_lang['strnoreportsdb'] = 'Vous n\'avez pas créé la base de données reports. Lisez le fichier INSTALL pour en savoir plus.';

	// Reports
	$plugin_lang['strreport'] = 'Rapport';
	$plugin_lang['strreports'] = 'Rapports';
	$plugin_lang['strshowallreports'] = 'Voir tous les rapports';
	$plugin_lang['strnoreports'] = 'Aucun rapport trouvé.';
	$plugin_lang['strcreatereport'] = 'Créer un rapport';
	$plugin_lang['streditreport'] = 'Éditer un rapport';
	$plugin_lang['strreportdropped'] = 'Rapport supprimé.';
	$plugin_lang['strreportdroppedbad'] = 'Échec lors de la suppression du rapport.';
	$plugin_lang['strconfdropreport'] = 'Êtes-vous sûr de vouloir supprimer le rapport « %s » ?';
	$plugin_lang['strreportneedsname'] = 'Vous devez indiquer un nom pour votre rapport.';
	$plugin_lang['strreportneedsdef'] = 'Vous devez fournir une requête SQL pour votre rapport.';
	$plugin_lang['strreportcreated'] = 'Rapport sauvegardé.';
	$plugin_lang['strreportcreatedbad'] = 'Échec lors de la sauvegarde du rapport.';
?>
