<?php

$ADODB_LANG_ARRAY = array (
			'LANG'                      => 'en',
            DB_ERROR                    => 'unknown error',
            DB_ERROR_ALREADY_EXISTS     => 'already exists',
            DB_ERROR_CANNOT_CREATE      => 'can not create',
            DB_ERROR_CANNOT_DELETE      => 'can not delete',
            DB_ERROR_CANNOT_DROP        => 'can not drop',
            DB_ERROR_CONSTRAINT         => 'constraint violation',
            DB_ERROR_DIVZERO            => 'division by zero',
            DB_ERROR_INVALID            => 'invalid',
            DB_ERROR_INVALID_DATE       => 'invalid date or time',
            DB_ERROR_INVALID_NUMBER     => 'invalid number',
            DB_ERROR_MISMATCH           => 'mismatch',
            DB_ERROR_NODBSELECTED       => 'no database selected',
            DB_ERROR_NOSUCHFIELD        => 'no such field',
            DB_ERROR_NOSUCHTABLE        => 'no such table',
            DB_ERROR_NOT_CAPABLE        => 'DB backend not capable',
            DB_ERROR_NOT_FOUND          => 'not found',
            DB_ERROR_NOT_LOCKED         => 'not locked',
            DB_ERROR_SYNTAX             => 'syntax error',
            DB_ERROR_UNSUPPORTED        => 'not supported',
            DB_ERROR_VALUE_COUNT_ON_ROW => 'value count on row',
            DB_ERROR_INVALID_DSN        => 'invalid DSN',
            DB_ERROR_CONNECT_FAILED     => 'connect failed',
            0	                       => 'no error', // DB_OK
            DB_ERROR_NEED_MORE_DATA     => 'insufficient data supplied',
            DB_ERROR_EXTENSION_NOT_FOUND=> 'extension not found',
            DB_ERROR_NOSUCHDB           => 'no such database',
            DB_ERROR_ACCESS_VIOLATION   => 'insufficient permissions'
);
?>