<?php

	/**
	 * Lithuanian language file for phpPgAdmin.  
	 * @maintainer artvras [artvras@users.sourceforge.net]
	 *
	 * $Id: lithuanian.php,v 1.0 2011/05/25 14:34:33 $
	 */ 

	 // Language and character set
	$lang['applang'] = 'Lietuvių';
	$lang['applocale'] = 'lt-LT';
	$lang['applangdir'] = 'ltr';

	// Welcome
	$lang['strintro'] = 'Sveiki atvykę į phpPgAdmin.';
	$lang['strppahome'] = 'phpPgAdmin pradinis puslapis';
	$lang['strpgsqlhome'] = 'PostgreSQL pradinis puslapis';
	$lang['strpgsqlhome_url'] = 'http://www.postgresql.org/';
	$lang['strlocaldocs'] = 'PostgreSQL dokumentacija (vietinė)';
	$lang['strreportbug'] = 'Pranešti apie klaidą';
	$lang['strviewfaq'] = 'Peržiūrėti internetinį DUK';
	$lang['strviewfaq_url'] = 'http://phppgadmin.sourceforge.net/doku.php?id=faq';
	
	// Basic strings
	$lang['strlogin'] = 'Prisijungti';
	$lang['strloginfailed'] = 'Nepavyko prisijungti';
	$lang['strlogindisallowed'] = 'Prisijungti neleidžiama saugumo sumetimais.';
	$lang['strserver'] = 'Serveris';
	$lang['strservers'] = 'Serveriai';
	$lang['strgroupservers'] = 'Serveriai grupėje "%s"';
	$lang['strallservers'] = 'Visi serveriai';
	$lang['strintroduction'] = 'Įžanga';//Pradžia
$lang['strhost'] = 'Host';//Pagrindinis kompiuteris
	$lang['strport'] = 'Prievadas';
	$lang['strlogout'] = 'Atsijungti';
	$lang['strowner'] = 'Valdytojas';//Savininkas
	$lang['straction'] = 'Veiksmas';
	$lang['stractions'] = 'Veiksmai';
	$lang['strname'] = 'Pavadinimas';
	$lang['strdefinition'] = 'Apibrėžtis';
	$lang['strproperties'] = 'Savybės';
	$lang['strbrowse'] = 'Peržiūrėti';//Naršyti
	$lang['strenable'] = 'Įjungti';
	$lang['strdisable'] = 'Išjungti';
	$lang['strdrop'] = 'Šalinti';
	$lang['strdropped'] = 'Pašalintas';
	$lang['strnull'] = 'Null';
	$lang['strnotnull'] = 'Ne Null';
	$lang['strprev'] = '< Ankstesnis';
	$lang['strnext'] = 'Tolesnis >';
	$lang['strfirst'] = '<< Pirmas';
	$lang['strlast'] = 'Paskutinis >>';
	$lang['strfailed'] = 'Nepavyko';
	$lang['strcreate'] = 'Sukurti';
	$lang['strcreated'] = 'Sukurta';
	$lang['strcomment'] = 'Komentaras';
	$lang['strlength'] = 'Ilgis';
	$lang['strdefault'] = 'Numatytoji reikšmė';//Numatytas(-a)
	$lang['stralter'] = 'Pakeisti';
	$lang['strok'] = 'Gerai';
	$lang['strcancel'] = 'Atsisakyti';
	$lang['strkill'] = 'Nutraukti';//Sunaikinti
	$lang['strac'] = 'Įjungti automatinį baigimą';
	$lang['strsave'] = 'Įrašyti';
	$lang['strreset'] = 'Atstatyti į pradinę būseną';//Atkurti
	$lang['strrestart'] = 'Paleisti iš naujo';
	$lang['strinsert'] = 'Įterpti';
	$lang['strselect'] = 'Atrinkti';
	$lang['strdelete'] = 'Šalinti';
	$lang['strupdate'] = 'Atnaujinti';
	$lang['strreferences'] = 'Rodyklės';
	$lang['stryes'] = 'Taip';
	$lang['strno'] = 'Ne';
	$lang['strtrue'] = 'TIESA';
	$lang['strfalse'] = 'NETIESA';
	$lang['stredit'] = 'Taisyti';
	$lang['strcolumn'] = 'Stulpelis';
	$lang['strcolumns'] = 'Stulpeliai';
	$lang['strrows'] = 'įrašas(-ai)';
	$lang['strrowsaff'] = 'įrašas(-ai) paveikti.';
	$lang['strobjects'] = 'objektas (-ai)';
	$lang['strback'] = 'Atgal';
	$lang['strqueryresults'] = 'Užklausos rezultatai';
	$lang['strshow'] = 'Rodyti';
	$lang['strempty'] = 'Išvalyti';//Šalinti turinį
	$lang['strlanguage'] = 'Kalba';
	$lang['strencoding'] = 'Koduotė';
	$lang['strvalue'] = 'Reikšmė';
	$lang['strunique'] = 'Unikalus';
	$lang['strprimary'] = 'Pirminis';
	$lang['strexport'] = 'Eksportuoti';
	$lang['strimport'] = 'Importuoti';
	$lang['strallowednulls'] = 'Leidžiami NULL simboliai';
	$lang['strbackslashn'] = '\N';
	$lang['stremptystring'] = 'Tuščia eilutė/laukas';
	$lang['strsql'] = 'SQL';
$lang['stradmin'] = 'Admin';//Administratorius
	$lang['strvacuum'] = 'Apvalyti';
	$lang['stranalyze'] = 'Analizuoti';
	$lang['strclusterindex'] = 'Pertvarkyti';
	$lang['strclustered'] = 'Sutvarkyta?';
	$lang['strreindex'] = 'Perindeksuoti';
	$lang['strexecute'] = 'Vykdyti';
	$lang['stradd'] = 'Pridėti';
	$lang['strevent'] = 'Įvykis';
	$lang['strwhere'] = 'Sąlyga';//Kur
	$lang['strinstead'] = 'Atlikti užuot';
	$lang['strwhen'] = 'Kai';
	$lang['strformat'] = 'Formatas';
	$lang['strdata'] = 'Duomenys';
	$lang['strconfirm'] = 'Patvirtinti';
	$lang['strexpression'] = 'Išraiška';
	$lang['strellipsis'] = '...';
	$lang['strseparator'] = ': ';
	$lang['strexpand'] = 'Išskleisti';
	$lang['strcollapse'] = 'Suskleisti';
	$lang['strfind'] = 'Ieškoti';
	$lang['stroptions'] = 'Parinktys';
	$lang['strrefresh'] = 'Atnaujinti';
	$lang['strdownload'] = 'Parsisiųsti';
	$lang['strdownloadgzipped'] = 'Parsisiųsti suspaustą su gzip';
	$lang['strinfo'] = 'Informacija';
	$lang['stroids'] = 'OIDs';
	$lang['stradvanced'] = 'Išplėstinis(-ė)';//papildomas(-a),
	$lang['strvariables'] = 'Kintamieji';
	$lang['strprocess'] = 'Procesas';
	$lang['strprocesses'] = 'Procesai';
	$lang['strsetting'] = 'Nuostata';//Parinktis
	$lang['streditsql'] = 'Redaguoti SQL';
	$lang['strruntime'] = 'Visa vykdymo trukmė: %s ms';
	$lang['strpaginate'] = 'Rezultatus skaidyti į puslapius';
	$lang['struploadscript'] = 'arba nusiųsti SQL skriptą:';
	$lang['strstarttime'] = 'Pradžios laikas';
	$lang['strfile'] = 'Failas';
	$lang['strfileimported'] = 'Failas importuotas.';
	$lang['strtrycred'] = 'Naudoti šiuos įgaliojimus visiems serveriams';
	$lang['strconfdropcred'] = 'Dėl saugumo, ryšio nutraukimas panaikins jūsų bendrą prisijungimo informaciją. Ar tikrai norite nutraukti ryšį ?';
	$lang['stractionsonmultiplelines'] = 'Veiksmai keliose eilutėse';
	$lang['strselectall'] = 'Visi';//Pažymėti visus
	$lang['strunselectall'] = 'Nieko';//Panaikinti žymėjimą visiems
	$lang['strlocale'] = 'Lokalė';
	$lang['strcollation'] = 'Rikiavimas';
$lang['strctype'] = 'Character Type';//Simbolių(ženklų) tipas
	$lang['strdefaultvalues'] = 'Numatytosios reikšmės';
	$lang['strnewvalues'] = 'Naujosios reikšmės';
	$lang['strstart'] = 'Paleisti';
	$lang['strstop'] = 'Stabdyti';
	$lang['strgotoppage'] = 'atgal į viršų';
	$lang['strtheme'] = 'Apipavidalinimas';
	$lang['strcluster'] = 'Klasteris';
	
	// Admin
	$lang['stradminondatabase'] = 'Šios administracinės užduotys taikomos visai %s duomenų bazei.';
	$lang['stradminontable'] = 'Šios administracinės užduotys taikomos lentelei %s.';
	
	// User-supplied SQL history
	$lang['strhistory'] = 'Praeitis';
	$lang['strnohistory'] = 'Nėra praeities.';
	$lang['strclearhistory'] = 'Išvalyti praeitį';
	$lang['strdelhistory'] = 'Šalinti iš praeities sąrašo';
	$lang['strconfdelhistory'] = 'Ar tikrai pašalinti šią užklausą iš preities sąrašo?';
	$lang['strconfclearhistory'] = 'Ar tikrai išvalyti praeitį?';
	$lang['strnodatabaseselected'] = 'Prašom pasirinkiti duomenų bazę.';

	// Database sizes
	$lang['strnoaccess'] = 'Nėra prieigos'; 
	$lang['strsize'] = 'Dydis';
	$lang['strbytes'] = 'baitai';
	$lang['strkb'] = 'kB';
	$lang['strmb'] = 'MB';
	$lang['strgb'] = 'GB';
	$lang['strtb'] = 'TB';

	// Error handling
	$lang['strnoframes'] = 'Ši programa geriausiai veikia su naršykle, kurioje palaikomi HTML rėmeliai(frames),tačiau gali būti naudojama be rėmelių spustelėjus toliau pateiktą nuorodą.';
	$lang['strnoframeslink'] = 'Naudoti be rėmelių';
	$lang['strbadconfig'] = 'Jūsų config.inc.php pasenęs. Reikia atkurti jį iš naujo config.inc.php-dist.';
	$lang['strnotloaded'] = 'Jūsų PHP įdiegimas nepalaiko PostgreSQL. Reikia perkompiliuoti PHP naudojant --with-pgsql konfigūravimo parametrą.';
	$lang['strpostgresqlversionnotsupported'] = 'PostgreSQL versija nepalaikoma. Prašom atnaujinti iki %s arba naujesnės versijos.';
	$lang['strbadschema'] = 'Nurodyta neteisinga schema.';
	$lang['strbadencoding'] = 'Nepavyko nustatyti kliento koduotės duomenų bazėje.';
	$lang['strsqlerror'] = 'SQL klaida:';
	$lang['strinstatement'] = 'Sakinyje:';
	$lang['strinvalidparam'] = 'Neteisingi skripto parametrai.';
	$lang['strnodata'] = 'Įrašų nerasta.';
	$lang['strnoobjects'] = 'Objektų nerasta.';
	$lang['strrownotunique'] = 'Šiame įraše nėra unikalaus identifikatoriaus.';
	$lang['strnouploads'] = 'Failų išsiuntimai - negalimi.';
	$lang['strimporterror'] = 'Importavimo klaida.';
	$lang['strimporterror-fileformat'] = 'Importavimo klaida: Nepavyko automatiškai nustatyti failo formato.';
	$lang['strimporterrorline'] = 'Importavimo klaida eilutėje %s.';
	$lang['strimporterrorline-badcolumnnum'] = 'Importavimo klaida eilutėje %s: Eilutėje neteisingas stulpelių skaičius.';
	$lang['strimporterror-uploadedfile'] = 'Importavimo klaida: Failas negali būti nusiųstas į serverį';
	$lang['strcannotdumponwindows'] = 'Atminties išklotinės suformavimas su sudėtingais lentelių ir schemų vardais Windows operacinėje sistemoje nepalaikomas';
	$lang['strinvalidserverparam'] = 'Bandymas prisijungti su negaliojančiu serverio parametru, galbūt kas nors bando nulaužti jūsų sistemą.'; 
	$lang['strnoserversupplied'] = 'Nenurodytas serveris!';
	$lang['strbadpgdumppath'] = 'Eksportavimo klaida: nepavyko įvykdyti pg_dump (pateiktas kelias Jūsų conf/config.inc.php : %s). Pataisykite šį kelią savo konfigūracijoje ir prisijunkite iš naujo.';
	$lang['strbadpgdumpallpath'] = 'Eksportavimo klaida: nepavyko įvykdyti pg_dumpall (pateiktas kelias Jūsų conf/config.inc.php : %s). Pataisykite šį kelią savo konfigūracijoje ir prisijunkite iš naujo.';
	$lang['strconnectionfail'] = 'Nepavyksta prisijungti prie serverio.';

	// Tables
	$lang['strtable'] = 'Lentelė';
	$lang['strtables'] = 'Lentelės';
	$lang['strshowalltables'] = 'Rodyti visas lenteles';
	$lang['strnotables'] = 'Lentelių nerasta.';
	$lang['strnotable'] = 'Lentelė nerasta.';
	$lang['strcreatetable'] = 'Sukurti lentelę';
	$lang['strcreatetablelike'] = 'Sukurti lentelę kaip';
	$lang['strcreatetablelikeparent'] = 'Pirminė lentelė';
	$lang['strcreatelikewithdefaults'] = 'ĮTRAUKTI NUMATYTĄSIAS REIKŠMES';
	$lang['strcreatelikewithconstraints'] = 'ĮTRAUKTI RIBOJIMUS';
	$lang['strcreatelikewithindexes'] = 'ĮTRAUKTI INDEKSUS';
	$lang['strtablename'] = 'Lentelės pavadinimas';
	$lang['strtableneedsname'] = 'Turite suteikti lentelei pavadinimą.';
	$lang['strtablelikeneedslike'] = 'Turite nurodyti lentelę, kurios savybes reikia kopijuoti.';
	$lang['strtableneedsfield'] = 'Turite nurodyti bent vieną lauką.';
	$lang['strtableneedscols'] = 'Turite nurodyti teisingą stulpelių skaičių.';
	$lang['strtablecreated'] = 'Lentelė sukurta.';
	$lang['strtablecreatedbad'] = 'Nepavyko sukurti lentelės.';
	$lang['strconfdroptable'] = 'Ar tikrai norite šalinti lentelę "%s"?';
	$lang['strtabledropped'] = 'Lentelė pašalinta.';
	$lang['strtabledroppedbad'] = 'Nepavyko pašalinti lentelės.';
	$lang['strconfemptytable'] = 'Ar tikrai norite išvalyti lentelę "%s"?';
	$lang['strtableemptied'] = 'Lentelė išvalyta.';
	$lang['strtableemptiedbad'] = 'Nepavyko išvalyti lentelės.';
	$lang['strinsertrow'] = 'Įterpti įrašą';
	$lang['strrowinserted'] = 'Įrašas įterptas.';
	$lang['strrowinsertedbad'] = 'Nepavyko įterpti įrašo.';
	$lang['strnofkref'] = 'Nėra atitinkamos reikšmės išoriniame rakte %s.';
	$lang['strrowduplicate'] = 'Nepavyko įterpti įrašo, bandyta dubliuoti įrašą.';
	$lang['streditrow'] = 'Taisyti įrašą';
	$lang['strrowupdated'] = 'Įrašas atnaujintas.';
	$lang['strrowupdatedbad'] = 'Nepavyko atnaujinti įrašo.';
	$lang['strdeleterow'] = 'Šalinti įrašą';
	$lang['strconfdeleterow'] = 'Ar tikrai norite šalinti šį įrašą?';
	$lang['strrowdeleted'] = 'Įrašas pašalintas.';
	$lang['strrowdeletedbad'] = 'Nepavyko pašalinti įrašo.';
	$lang['strinsertandrepeat'] = 'Įterpti ir kartoti';
	$lang['strnumcols'] = 'Stulpelių skaičius';
	$lang['strcolneedsname'] = 'Turite nurodyti stulpelio pavadinimą';
	$lang['strselectallfields'] = 'Pažymėti visus laukus';
	$lang['strselectneedscol'] = 'Turite rodyti bent vieną stulpelį.';
	$lang['strselectunary'] = 'Vienviečiai operatoriai negali turėti reikšmių.';
	$lang['strcolumnaltered'] = 'Stulpelis pakeistas.';
	$lang['strcolumnalteredbad'] = 'Nepavyko pakeisti stulpelio.';
	$lang['strconfdropcolumn'] = 'Ar tikrai norite šalinti stulpelį "%s" iš lentelės "%s"?';
	$lang['strcolumndropped'] = 'Stulpelis pašalintas.';
	$lang['strcolumndroppedbad'] = 'Nepavyko pašalinti stulpelio.';
	$lang['straddcolumn'] = 'Pridėti stulpelį';
	$lang['strcolumnadded'] = 'Stulpelis pridėtas.';
	$lang['strcolumnaddedbad'] = 'Nepavyko pridėti stulpelio.';
$lang['strcascade'] = 'CASCADE';//Pakopinis
	$lang['strtablealtered'] = 'Lentelė pakeista.';
	$lang['strtablealteredbad'] = 'Nepavyko pakeisti lentelės.';
	$lang['strdataonly'] = 'Tik duomenis';
	$lang['strstructureonly'] = 'Tik struktūrą';
	$lang['strstructureanddata'] = 'Struktūrą ir duomenis';
$lang['strtabbed'] = 'Tabbed';//Atskirtas tabuliavimo žymėmis
$lang['strauto'] = 'Auto';
	$lang['strconfvacuumtable'] = 'Ar tikrai norite apvalyti "%s"?';
	$lang['strconfanalyzetable'] = 'Ar tikrai norite analizuoti "%s"?';
	$lang['strconfreindextable'] = 'Ar tikrai norite perindeksuoti "%s"?';
	$lang['strconfclustertable'] = 'Ar tikrai norite sutvarkyti "%s"?';
	$lang['strestimatedrowcount'] = 'Apskaičiuotasis įrašų skaičius';//Apytikris
	$lang['strspecifytabletoanalyze'] = 'Turite nurodyti bent vieną lentelę, kuri turi būti išanalizuota.';
	$lang['strspecifytabletoempty'] = 'Turite nurodyti bent vieną lentelę, kuri turi būti išvalyta.';
	$lang['strspecifytabletodrop'] = 'Turite nurodyti bent vieną lentelę, kuri turi būti pašalinta.';
	$lang['strspecifytabletovacuum'] = 'Turite nurodyti bent vieną lentelę, kuri turi būti apvalyta.';
	$lang['strspecifytabletoreindex'] = 'Turite nurodyti bent vieną lentelę, kuri turi būti perindeksuota.';
	$lang['strspecifytabletocluster'] = 'Turite nurodyti bent vieną lentelę, kuri turi būti sutvarkyta.';
	$lang['strnofieldsforinsert'] = 'Negalite įterpti įrašo į lentelę be stulpelių.';

	// Columns
	$lang['strcolprop'] = 'Stulpelio savybės';
	$lang['strnotableprovided'] = 'Nenurodyta lentelė!';
		
	// Users
	$lang['struser'] = 'Naudotojas';
	$lang['strusers'] = 'Naudotojai';
	$lang['strusername'] = 'Naudotojo vardas';
	$lang['strpassword'] = 'Slaptažodis';
$lang['strsuper'] = 'Superuser?';
	$lang['strcreatedb'] = 'Gali kurti DB?';
	$lang['strexpires'] = 'Baigia galioti';
	$lang['strsessiondefaults'] = 'Seanso numatytosios reikšmės';
	$lang['strnousers'] = 'Naudotojų nerasta.';
	$lang['struserupdated'] = 'Naudotojas atnaujintas.';
	$lang['struserupdatedbad'] = 'Nepavyko atnaujinti naudotojo.';
	$lang['strshowallusers'] = 'Rodyti visus naudotojus';
	$lang['strcreateuser'] = 'Kurti naudotoją';
	$lang['struserneedsname'] = 'Turite suteikti naudotojui vardą.';
	$lang['strusercreated'] = 'Naudotojas sukurtas.';
	$lang['strusercreatedbad'] = 'Nepavyko sukurti naudotojo.';
	$lang['strconfdropuser'] = 'Ar tikrai norite pašalinti naudotoją "%s"?';
	$lang['struserdropped'] = 'Naudotojas pašalintas.';
	$lang['struserdroppedbad'] = 'Nepavyko pašalinti naudotojo.';
	$lang['straccount'] = 'Paskyra';
	$lang['strchangepassword'] = 'Keisti slaptažodį';
	$lang['strpasswordchanged'] = 'Slaptažodis pakeistas.';
	$lang['strpasswordchangedbad'] = 'Nepavyko pakeisti slaptažodžio.';
	$lang['strpasswordshort'] = 'Slaptažodis per trumpas.';
	$lang['strpasswordconfirm'] = 'Slaptažodis neatitinka patvirtinimo.';
	
	// Groups
	$lang['strgroup'] = 'Grupė';
	$lang['strgroups'] = 'Grupės';
	$lang['strshowallgroups'] = 'Rodyti visas grupes';
	$lang['strnogroup'] = 'Grupė nerasta.';
	$lang['strnogroups'] = 'Grupių nerasta.';
	$lang['strcreategroup'] = 'Kurti grupę';
	$lang['strgroupneedsname'] = 'Turite suteikti grupei pavadinimą.';
	$lang['strgroupcreated'] = 'Grupė sukurta.';
	$lang['strgroupcreatedbad'] = 'Nepavyko sukurti grupės.';	
	$lang['strconfdropgroup'] = 'Ar tikrai norite šalinti grupę "%s"?';
	$lang['strgroupdropped'] = 'Grupė pašalinta.';
	$lang['strgroupdroppedbad'] = 'Nepavyko pašalinti grupės.';
	$lang['strmembers'] = 'Nariai';
	$lang['strmemberof'] = 'Yra narys';
	$lang['stradminmembers'] = 'Admin nariai';
	$lang['straddmember'] = 'Pridėti narį';
	$lang['strmemberadded'] = 'Narys pridėtas.';
	$lang['strmemberaddedbad'] = 'Nepavyko pridėti nario.';
	$lang['strdropmember'] = 'Šalinti narį';
	$lang['strconfdropmember'] = 'Ar tikrai norite šalinti narį "%s" iš grupės "%s"?';
	$lang['strmemberdropped'] = 'Narys pašalintas.';
	$lang['strmemberdroppedbad'] = 'Nepavyko pašalinti nario.';

	// Roles
	$lang['strrole'] = 'Rolė';
	$lang['strroles'] = 'Rolės';
	$lang['strshowallroles'] = 'Rodyti roles';
	$lang['strnoroles'] = 'Rolių nerasta.';
	$lang['strinheritsprivs'] = 'Paveldi privilegijas?';
	$lang['strcreaterole'] = 'Kurti rolę';
	$lang['strcancreaterole'] = 'Gali kurti rolę?';
	$lang['strrolecreated'] = 'Rolė sukurta.';
	$lang['strrolecreatedbad'] = 'Nepavyko sukurti rolės.';
	$lang['strrolealtered'] = 'Rolė pakeista.';
	$lang['strrolealteredbad'] = 'Nepavyko pakeisti rolės.';
	$lang['strcanlogin'] = 'Gali prisijungti?';
	$lang['strconnlimit'] = 'Sujungimų limitas';
	$lang['strdroprole'] = 'Šalinti rolę';
	$lang['strconfdroprole'] = 'Ar tikrai norite šalinti rolę "%s"?';
	$lang['strroledropped'] = 'Rolė pašalinta.';
	$lang['strroledroppedbad'] = 'Nepavyko pašalinti rolės.';
	$lang['strnolimit'] = 'Be ribojimų';
	$lang['strnever'] = 'Niekada';
	$lang['strroleneedsname'] = 'Turite suteikti rolei pavadinimą.';

	// Privileges
	$lang['strprivilege'] = 'Privilegija';
	$lang['strprivileges'] = 'Privilegijos';
	$lang['strnoprivileges'] = 'Šiam objektui taikomos numatytosios valdytojo privilegijos.';
	$lang['strgrant'] = 'Suteikti';
	$lang['strrevoke'] = 'Panaikinti';//Atšaukti
	$lang['strgranted'] = 'Privilegijos pakeistos.';
	$lang['strgrantfailed'] = 'Nepavyko pakeisti privilegijų.';
	$lang['strgrantbad'] = 'Turite nurodyti bent vieną naudotoją arba grupę ir bent vieną privilegiją.';
	$lang['strgrantor'] = 'Teikėjas';
	$lang['strasterisk'] = '*';

	// Databases
	$lang['strdatabase'] = 'Duomenų bazė';
	$lang['strdatabases'] = 'Duomenų bazės';
	$lang['strshowalldatabases'] = 'Rodyti duomenų bazes';
	$lang['strnodatabases'] = 'Duomenų bazių nerasta.';
	$lang['strcreatedatabase'] = 'Kurti duomenų bazę';
	$lang['strdatabasename'] = 'Duomenų bazės pavadinimas';
	$lang['strdatabaseneedsname'] = 'Turite suteikti duomenų bazei pavadinimą.';
	$lang['strdatabasecreated'] = 'Duomenų bazė sukurta.';
	$lang['strdatabasecreatedbad'] = 'Nepavyko sukurti duomenų bazės.';
	$lang['strconfdropdatabase'] = 'Ar tikrai norite šalinti duomenų bazę "%s"?';
	$lang['strdatabasedropped'] = 'Duomenų bazė pašalinta.';
	$lang['strdatabasedroppedbad'] = 'Nepavyko pašalinti duomenų bazės.';
	$lang['strentersql'] = 'Įveskite SQL užklausą žemiau:';
	$lang['strsqlexecuted'] = 'SQL užklausa įvykdyta.';
	$lang['strvacuumgood'] = 'Apvalymas atliktas.';
	$lang['strvacuumbad'] = 'Nepavyko atlikti apvalymo.';
	$lang['stranalyzegood'] = 'Analizė atlikta.';
	$lang['stranalyzebad'] = 'Nepavyko atlikti analizės.';
	$lang['strreindexgood'] = 'Perindeksavimas atliktas.';
	$lang['strreindexbad'] = 'Perindeksavimas nepavyko.';
	$lang['strfull'] = 'Visiškas';
$lang['strfreeze'] = 'Freeze';
$lang['strforce'] = 'Force';
	$lang['strsignalsent'] = 'Signalas išsiųstas.';
	$lang['strsignalsentbad'] = 'Nepavyko išsiųsti signalo.';
	$lang['strallobjects'] = 'Visi objektai';
	$lang['strdatabasealtered'] = 'Duomenų bazė pakeista.';
	$lang['strdatabasealteredbad'] = 'Nepavyko pakeisti duomenų bazės.';
	$lang['strspecifydatabasetodrop'] = 'Turite nurodyti bent vieną duomenų bazę, kurią reikia šalinti.';
	$lang['strtemplatedb'] = 'Šablonas';
	$lang['strconfanalyzedatabase'] = 'Ar tikrai norite analizuoti visas lenteles duomenų bazėje "%s"?';
	$lang['strconfvacuumdatabase'] = 'Ar tikrai norite apvalyti visas lenteles duomenų bazėje "%s"?';
	$lang['strconfreindexdatabase'] = 'Ar tikrai norite perindeksuoti visas lenteles duomenų bazėje "%s"?';
	$lang['strconfclusterdatabase'] = 'Ar tikrai norite sutvarkyti visas lenteles duomenų bazėje "%s"?';

	// Views
	$lang['strview'] = 'Rodinys';
	$lang['strviews'] = 'Rodiniai';
	$lang['strshowallviews'] = 'Rodyti visus rodinius';
	$lang['strnoview'] = 'Rodinys nerastas.';
	$lang['strnoviews'] = 'Rodinių nerasta.';
	$lang['strcreateview'] = 'Kurti rodinį';
	$lang['strviewname'] = 'Rodinio pavadinimas';
	$lang['strviewneedsname'] = 'Turite suteikti rodiniui pavadinimą.';
	$lang['strviewneedsdef'] = 'Turite pateikti rodinio apibrėžtį.';
	$lang['strviewneedsfields'] = 'Turite nurodyti stulpelius, kurie turi būti rodinyje.';
	$lang['strviewcreated'] = 'Rodinys sukurtas.';
	$lang['strviewcreatedbad'] = 'Nepavyko sukurti rodinio.';
	$lang['strconfdropview'] = 'Ar tikrai norite pašalinti rodinį "%s"?';
	$lang['strviewdropped'] = 'Rodinys pašalintas.';
	$lang['strviewdroppedbad'] = 'Nepavyko pašalinti rodinio.';
	$lang['strviewupdated'] = 'Rodinys atnaujintas.';
	$lang['strviewupdatedbad'] = 'Nepavyko atnaujinti rodinio.';
	$lang['strviewlink'] = 'Saistantys raktai';
	$lang['strviewconditions'] = 'Papildomos sąlygos';
	$lang['strcreateviewwiz'] = 'Kurti rodinį su vedikliu';
	$lang['strrenamedupfields'] = 'Pervadinti dubliuojančiuosius laukus';
	$lang['strdropdupfields'] = 'Pašalinti dubliuojančiuosius laukus';
	$lang['strerrordupfields'] = 'Klaida dubliuojančiuose laukuose';
	$lang['strviewaltered'] = 'Rodinys pakeistas.';
	$lang['strviewalteredbad'] = 'Nepavyko pakeisti rodinio.';
	$lang['strspecifyviewtodrop'] = 'Turite nurodyti bent vieną rodinį, kurį norite pašalinti.';

	// Sequences
	$lang['strsequence'] = 'Seka';
	$lang['strsequences'] = 'Sekos';
	$lang['strshowallsequences'] = 'Rodyti visas sekas';
	$lang['strnosequence'] = 'Seka nerasta.';
	$lang['strnosequences'] = 'Sekų nerasta.';
	$lang['strcreatesequence'] = 'Kurti seką';
	$lang['strlastvalue'] = 'Paskutinė reikšmė';
	$lang['strincrementby'] = 'Prieaugis';	
	$lang['strstartvalue'] = 'Pradinė reikšmė';
	$lang['strrestartvalue'] = 'Paleidimo iš naujo reikšmė';
	$lang['strmaxvalue'] = 'Maks. reikšmė';
	$lang['strminvalue'] = 'Min. reikšmė';
	$lang['strcachevalue'] = 'Reikšmė podėlyje';
$lang['strlogcount'] = 'Log count';
$lang['strcancycle'] = 'Can cycle?';//Gali kartotis?
	$lang['striscalled'] = 'Padidins paskutinę reikšmę prieš grąžinant kitą reikšmę (is_called)?';
	$lang['strsequenceneedsname'] = 'Turite suteikti sekai vardą.';
	$lang['strsequencecreated'] = 'Seka sukurta.';
	$lang['strsequencecreatedbad'] = 'Nepavyko sukurti sekos.';
	$lang['strconfdropsequence'] = 'Ar tikrai norite pašalinti seką "%s"?';
	$lang['strsequencedropped'] = 'Seka pašalinta.';
	$lang['strsequencedroppedbad'] = 'Nepavyko pašalinti sekos.';
	$lang['strsequencerestart'] = 'Seka paleista iš naujo.';
	$lang['strsequencerestartbad'] = 'Nepavyko sekos paleist iš naujo.';
	$lang['strsequencereset'] = 'Seka atstatyta į pradinę būseną.';
	$lang['strsequenceresetbad'] = 'Nepavyko sekos atstatyti į pradinę būseną.';
 	$lang['strsequencealtered'] = 'Seka pakeista.';
 	$lang['strsequencealteredbad'] = 'Nepavyko pakeisti sekos.';
 	$lang['strsetval'] = 'Nustatyti reikšmę';
 	$lang['strsequencesetval'] = 'Sekos reikšmė nustatyta.';
 	$lang['strsequencesetvalbad'] = 'Nepavyko nustatyti sekos reikšmės.';
 	$lang['strnextval'] = 'Padidinti reikšmę';
 	$lang['strsequencenextval'] = 'Sekos reikšmė padidėjo.';
 	$lang['strsequencenextvalbad'] = 'Sekos reikšmės padidinti nepavyko.';
	$lang['strspecifysequencetodrop'] = 'Turite nurodyti bent vieną seką, kurią norite pašalinti.';
	
	// Indexes
	$lang['strindex'] = 'Indeksas';
	$lang['strindexes'] = 'Indeksai';
	$lang['strindexname'] = 'Indekso pavadinimas';
	$lang['strshowallindexes'] = 'Rodyti visus indeksus';
	$lang['strnoindex'] = 'Indeksas nerastas.';
	$lang['strnoindexes'] = 'Indeksų nerasta.';
	$lang['strcreateindex'] = 'Kurti indeksą';
	$lang['strtabname'] = 'Lentelės pavadinimas';
	$lang['strcolumnname'] = 'Stulpelio pavadinimas';
	$lang['strindexneedsname'] = 'Turite suteikti indeksui pavadinimą.';
	$lang['strindexneedscols'] = 'Turite nurodyti teisingą stulpelių skaičių.';
	$lang['strindexcreated'] = 'Indeksas sukurtas.';
	$lang['strindexcreatedbad'] = 'Nepavyko sukurti indekso.';
	$lang['strconfdropindex'] = 'Ar tikrai norite pašalinti indeksą "%s"?';
	$lang['strindexdropped'] = 'Indeksas pašalintas.';
	$lang['strindexdroppedbad'] = 'Nepavyko pašalinti indekso.';
	$lang['strkeyname'] = 'Rakto pavadinimas';
	$lang['struniquekey'] = 'Unikalus raktas';
	$lang['strprimarykey'] = 'Pirminis raktas';
 	$lang['strindextype'] = 'Indekso tipas';
	$lang['strtablecolumnlist'] = 'Stulpeliai lentelėje';
	$lang['strindexcolumnlist'] = 'Stulpeliai indekse';
	$lang['strconfcluster'] = 'Ar tikrai norite pertvarkyti "%s"?';
	$lang['strclusteredgood'] = 'Pertvarka atlikta.';
	$lang['strclusteredbad'] = 'Nepavyko atlikti pertvarkos.';
	$lang['strconcurrently'] = 'Lygiagrečiai';//tuo pat metu
	$lang['strnoclusteravailable'] = 'Lentelė nesutvarkyta pagal indeksą.';

	// Rules
	$lang['strrules'] = 'Taisyklės';
	$lang['strrule'] = 'Taisyklė';
	$lang['strshowallrules'] = 'Rodyti visas taisykles';
	$lang['strnorule'] = 'Taisyklė nerasta.';
	$lang['strnorules'] = 'Taisyklių nerasta.';
	$lang['strcreaterule'] = 'Kurti taisyklę';
	$lang['strrulename'] = 'Taisyklės pavadinimas';
	$lang['strruleneedsname'] = 'Turite suteikti taisyklei pavadinimą.';
	$lang['strrulecreated'] = 'Taisyklė sukurta.';
	$lang['strrulecreatedbad'] = 'Nepavyko sukurti taisyklės.';
	$lang['strconfdroprule'] = 'Ar tikrai norite šalinti taisyklę "%s" taikomą "%s"?';
	$lang['strruledropped'] = 'Taisyklė pašalinta.';
	$lang['strruledroppedbad'] = 'Nepavyko pašalinti taisyklės.';

	// Constraints
	$lang['strconstraint'] = 'Ribojimas';
	$lang['strconstraints'] = 'Ribojimai';
	$lang['strshowallconstraints'] = 'Rodyti visus ribojimus';
	$lang['strnoconstraints'] = 'Ribojimų nerasta.';
	$lang['strcreateconstraint'] = 'Kurti ribojimą';
	$lang['strconstraintcreated'] = 'Ribojimas sukurtas.';
	$lang['strconstraintcreatedbad'] = 'Nepavyko sukurti ribojimo.';
	$lang['strconfdropconstraint'] = 'Ar tikrai norite šalinti ribojimą "%s" lentelei "%s"?';
	$lang['strconstraintdropped'] = 'Ribojimas pašalintas.';
	$lang['strconstraintdroppedbad'] = 'Nepavyko pašalinti ribojimo.';
	$lang['straddcheck'] = 'Pridėti tikrinimą';
	$lang['strcheckneedsdefinition'] = 'Tikrinimo ribojimui būtina apibrėžtis.';
	$lang['strcheckadded'] = 'Tikrinimo ribojimas pridėtas.';
	$lang['strcheckaddedbad'] = 'Nepavyko pridėti tikrinimo ribojimo.';
	$lang['straddpk'] = 'Pridėti pirminį raktą';
	$lang['strpkneedscols'] = 'Pirminiam raktui būtina priskirti bent vieną stulpelį.';
	$lang['strpkadded'] = 'Pirminis raktas pridėtas.';
	$lang['strpkaddedbad'] = 'Nepavyko pridėti pirminio rakto.';
	$lang['stradduniq'] = 'Pridėti unikalų raktą';
	$lang['struniqneedscols'] = 'Unikaliam raktui būtina priskirti bent vieną stulpelį.';
	$lang['struniqadded'] = 'Unikalus raktas pridėtas.';
	$lang['struniqaddedbad'] = 'Nepavyko pridėti unikalaus rakto.';
	$lang['straddfk'] = 'Pridėti išorinį raktą';
	$lang['strfkneedscols'] = 'Išoriniam raktui būtina priskirti bent vieną stulpelį.';
	$lang['strfkneedstarget'] = 'Būtina nurodyti išorinio rakto paskirties lentelę.';
	$lang['strfkadded'] = 'Išorinis raktas pridėtas.';
	$lang['strfkaddedbad'] = 'Nepavyko pridėti išorinio rakto.';
	$lang['strfktarget'] = 'Paskirties lentelė';
	$lang['strfkcolumnlist'] = 'Rakto stulpeliai';
	$lang['strondelete'] = 'šalinant';
	$lang['stronupdate'] = 'atnaujinant';

	// Functions
	$lang['strfunction'] = 'Funkcija';
	$lang['strfunctions'] = 'Funkcijos';
	$lang['strshowallfunctions'] = 'Rodyti visas funkcijas';
	$lang['strnofunction'] = 'Funkcija nerasta.';
	$lang['strnofunctions'] = 'Funkcijų nerasta.';
	$lang['strcreateplfunction'] = 'Kurti SQL/PL funkciją';
	$lang['strcreateinternalfunction'] = 'Kurti vidinę funkciją';
	$lang['strcreatecfunction'] = 'Kurti C funkciją';
	$lang['strfunctionname'] = 'Funkcijos pavadinimas';
	$lang['strreturns'] = 'Grąžina';
	$lang['strproglanguage'] = 'Programavimo kalba';
	$lang['strfunctionneedsname'] = 'Turite suteikti funkcijai pavadinimą.';
	$lang['strfunctionneedsdef'] = 'Turite pateikti funkcijos apibrėžtį.';
	$lang['strfunctioncreated'] = 'Funkcija sukurta.';
	$lang['strfunctioncreatedbad'] = 'Nepavyko sukurti funkcijos.';
	$lang['strconfdropfunction'] = 'Ar tikrai norite šalinti funkciją "%s"?';
	$lang['strfunctiondropped'] = 'Funkcija pašalinta.';
	$lang['strfunctiondroppedbad'] = 'Nepavyko pašalinti funkcijos.';
	$lang['strfunctionupdated'] = 'Funkcija atnaujinta.';
	$lang['strfunctionupdatedbad'] = 'Nepavyko atnaujinti funkcijos.';
	$lang['strobjectfile'] = 'Objektinis Failas';
	$lang['strlinksymbol'] = 'Sąsajos simbolis (C funkcijos pavadinimas)';
	$lang['strarguments'] = 'Argumentai';
	$lang['strargmode'] = 'Veiksena';
	$lang['strargtype'] = 'Tipas';
	$lang['strargadd'] = 'Pridėti dar vieną argumentą';
	$lang['strargremove'] = 'Pašalinti šį argumentą';
	$lang['strargnoargs'] = 'Ši funkcija nepriims jokių argumentų.';
	$lang['strargenableargs'] = 'Leisti perduoti argumentus šiai funkcijai.';
	$lang['strargnorowabove'] = 'Turi būti eilutė virš šios eilutės.';
	$lang['strargnorowbelow'] = 'Turi būti eilutė žemiau šios eilutės.';
	$lang['strargraise'] = 'Pakelti.';
	$lang['strarglower'] = 'Nuleisti.';
	$lang['strargremoveconfirm'] = 'Ar tikrai norite pašalinti šį argumentą? Pašalinimas negalės būti atšauktas.';
$lang['strfunctioncosting'] = 'Function Costing';
	$lang['strresultrows'] = 'Eilučių rezultate';
	$lang['strexecutioncost'] = 'Vykdymo sąnaudos';
	$lang['strspecifyfunctiontodrop'] = 'Turite nurodyti bent vieną funkciją, kurią norite pašalinti.';

	// Triggers
	$lang['strtrigger'] = 'Trigeris';
	$lang['strtriggers'] = 'Trigeriai';
	$lang['strshowalltriggers'] = 'Rodyti visus trigerius';
	$lang['strnotrigger'] = 'Trigeris nerastas.';
	$lang['strnotriggers'] = 'Trigerių nerasta.';
	$lang['strcreatetrigger'] = 'Kurti trigerį';
	$lang['strtriggerneedsname'] = 'Turite nurodyti trigerio pavadinimą.';
	$lang['strtriggerneedsfunc'] = 'Turite priskirti funkciją trigeriui.';
	$lang['strtriggercreated'] = 'Trigeris sukurtas.';
	$lang['strtriggercreatedbad'] = 'Nepavyko sukurti trigerio.';
	$lang['strconfdroptrigger'] = 'Ar tikrai norite šalinti trigerį "%s" lentelėje "%s"?';
	$lang['strconfenabletrigger'] = 'Ar tikrai norite įjungti trigerį "%s" lentelėje "%s"?';
	$lang['strconfdisabletrigger'] = 'Ar tikrai norite išjungti trigerį "%s" lentelėje "%s"?';
	$lang['strtriggerdropped'] = 'Trigeris pašalintas.';
	$lang['strtriggerdroppedbad'] = 'Nepavyko pašalinti trigerio.';
	$lang['strtriggerenabled'] = 'Trigeris įjungtas.';
	$lang['strtriggerenabledbad'] = 'Nepavyko įjungti trigerio.';
	$lang['strtriggerdisabled'] = 'Trigeris išjungtas.';
	$lang['strtriggerdisabledbad'] = 'Nepavyko išjungti trigerio.';
	$lang['strtriggeraltered'] = 'Trigeris pakeistas.';
	$lang['strtriggeralteredbad'] = 'Nepavyko pakeisti trigerio.';
	$lang['strforeach'] = 'Kiekvienam(-ai)';

	// Types
	$lang['strtype'] = 'Duomenų tipas';
	$lang['strtypes'] = 'Duomenų tipai';
	$lang['strshowalltypes'] = 'Rodyti visus duomenų tipus';
	$lang['strnotype'] = 'Duomenų tipas nerastas.';
	$lang['strnotypes'] = 'Duomenų tipų nerasta.';
	$lang['strcreatetype'] = 'Kurti duomenų tipą';
	$lang['strcreatecomptype'] = 'Kurti struktūrinį duomenų tipą';
	$lang['strcreateenumtype'] = 'Kurti enum duomenų tipą';
	$lang['strtypeneedsfield'] = 'Turite nurodyti bent vieną lauką.';
	$lang['strtypeneedsvalue'] = 'Turite nurodyti bent vieną reikšmę.';
	$lang['strtypeneedscols'] = 'Turite nurodyti teisingą laukų skaičių.';
	$lang['strtypeneedsvals'] = 'Turite nurodyti teisingą reikšmių skaičių.';
	$lang['strinputfn'] = 'Įvesties funkcija';
	$lang['stroutputfn'] = 'Išvesties funkcija';
	$lang['strpassbyval'] = 'Perdavimas reikšme?';
	$lang['stralignment'] = 'Lygiavimas';
	$lang['strelement'] = 'Elementas';
	$lang['strdelimiter'] = 'Skirtukas';
	$lang['strstorage'] = 'Atmintinė';
	$lang['strfield'] = 'Laukas';
	$lang['strnumfields'] = 'Laukų sk.';
	$lang['strnumvalues'] = 'Reikšmių sk.';
	$lang['strtypeneedsname'] = 'Turite suteikti duomenų tipui pavadinimą.';
	$lang['strtypeneedslen'] = 'Turite nurodyti duomenų tipo ilgį.';
	$lang['strtypecreated'] = 'Duomenų tipas sukurtas.';
	$lang['strtypecreatedbad'] = 'Nepavyko sukurti duomenų tipo.';
	$lang['strconfdroptype'] = 'Ar tikrai norite šalinti duomenų tipą "%s"?';
	$lang['strtypedropped'] = 'Duomenų tipas pašalintas.';
	$lang['strtypedroppedbad'] = 'Nepavyko pašalinti duomenų tipo.';
	$lang['strflavor'] = 'Atmaina';
	$lang['strbasetype'] = 'Bazinis';
	$lang['strcompositetype'] = 'Struktūrinis';
	$lang['strpseudotype'] = 'Pseudo';
$lang['strenum'] = 'Enum';
	$lang['strenumvalues'] = 'Enum reikšmės';

	// Schemas
	$lang['strschema'] = 'Schema';
	$lang['strschemas'] = 'Schemos';
	$lang['strshowallschemas'] = 'Rodyti visas schemas';
	$lang['strnoschema'] = 'Schema nerasta.';
	$lang['strnoschemas'] = 'Schemų nerasta.';
	$lang['strcreateschema'] = 'Kurti schemą';
	$lang['strschemaname'] = 'Schemos pavadinimas';
	$lang['strschemaneedsname'] = 'Turite suteikti schemai pavadinimą.';
	$lang['strschemacreated'] = 'Schema sukurta.';
	$lang['strschemacreatedbad'] = 'Nepavyko sukurti schemos.';
	$lang['strconfdropschema'] = 'Ar tikrai norite šalinti schemą "%s"?';
	$lang['strschemadropped'] = 'Schema pašalinta.';
	$lang['strschemadroppedbad'] = 'Nepavyko pašalinti schemos.';
	$lang['strschemaaltered'] = 'Schema pakeista.';
	$lang['strschemaalteredbad'] = 'Nepavyko pakeisti schemos.';
	$lang['strsearchpath'] = 'Schemų paieškos kelias';
	$lang['strspecifyschematodrop'] = 'Turite nurodyti bent vieną schemą, kurią norite pašalinti.';

	// Reports

	// Domains
	$lang['strdomain'] = 'Domenas';
	$lang['strdomains'] = 'Domenai';
	$lang['strshowalldomains'] = 'Rodyti visus domenus';
	$lang['strnodomains'] = 'Domenų nerasta.';
	$lang['strcreatedomain'] = 'Kurti domeną';
	$lang['strdomaindropped'] = 'Domenas pašalintas.';
	$lang['strdomaindroppedbad'] = 'Nepavyko pašalinti domeno.';
	$lang['strconfdropdomain'] = 'Ar tikrai norite šalinti domeną "%s"?';
	$lang['strdomainneedsname'] = 'Turite suteikti domenui vardą.';
	$lang['strdomaincreated'] = 'Domenas sukurtas.';
	$lang['strdomaincreatedbad'] = 'Nepavyko sukurti domeno.';	
	$lang['strdomainaltered'] = 'Domenas pakeistas.';
	$lang['strdomainalteredbad'] = 'Nepavyko pakeisti domeno.';	

	// Operators
	$lang['stroperator'] = 'Operatorius';
	$lang['stroperators'] = 'Operatoriai';
	$lang['strshowalloperators'] = 'Rodyti visus operatorius';
	$lang['strnooperator'] = 'Operatorius nerastas.';
	$lang['strnooperators'] = 'Operatorių nerasta.';
	$lang['strcreateoperator'] = 'Kurti operatorių';
	$lang['strleftarg'] = 'Kairiojo argumento tipas';
	$lang['strrightarg'] = 'Dešiniojo argumento tipas';
$lang['strcommutator'] = 'Commutator';//komutatyvumas, perstatomumas,
$lang['strnegator'] = 'Negator';//inversija,neigimas, neigimo operacija
$lang['strrestrict'] = 'Restrict';//ribojimas
$lang['strjoin'] = 'Join';
$lang['strhashes'] = 'Hashes';
$lang['strmerges'] = 'Merges';
$lang['strleftsort'] = 'Left sort';
$lang['strrightsort'] = 'Right sort';
	$lang['strlessthan'] = 'Mažiau nei';
	$lang['strgreaterthan'] = 'Daugiau nei';
	$lang['stroperatorneedsname'] = 'Turite suteikti operatoriui pavadinimą.';
	$lang['stroperatorcreated'] = 'Operatorius sukurtas.';
	$lang['stroperatorcreatedbad'] = 'Nepavyko sukurti operatoriaus.';
	$lang['strconfdropoperator'] = 'Ar tikrai norite šalinti operatorių "%s"?';
	$lang['stroperatordropped'] = 'Operatorius pašalintas.';
	$lang['stroperatordroppedbad'] = 'Nepavyko pašalinti operatoriaus.';

	// Casts
$lang['strcasts'] = 'Casts';//duomenų tipo keitimas
$lang['strnocasts'] = 'No casts found.';
$lang['strsourcetype'] = 'Source type';
$lang['strtargettype'] = 'Target type';
$lang['strimplicit'] = 'Implicit';//numanomas(-a)
$lang['strinassignment'] = 'In assignment';
$lang['strbinarycompat'] = '(Binary compatible)';//suderintas(-a) su dvejetainė sistema
	
	// Conversions
	$lang['strconversions'] = 'Konvertavimai';
	$lang['strnoconversions'] = 'Konvertavimai nerasti.';
$lang['strsourceencoding'] = 'Source encoding';//pradinė koduotė
$lang['strtargetencoding'] = 'Target encoding';//galutinė koduotė
	
	// Languages
	$lang['strlanguages'] = 'Programavimo kalbos';
	$lang['strnolanguages'] = 'Kalbų nerasta.';
	$lang['strtrusted'] = 'Patikima';
	
	// Info
	$lang['strnoinfo'] = 'Nėra informacijos.';
	$lang['strreferringtables'] = 'Priklausomos lentelės';
	$lang['strparenttables'] = 'Viršlentelės';
	$lang['strchildtables'] = 'Polentelės';

	// Aggregates
	$lang['straggregate'] = 'Agregavimo funkcija';
	$lang['straggregates'] = 'Agregavimo funkcijos';
	$lang['strnoaggregates'] = 'Agregavimo funkcijų nerasta.';
	$lang['stralltypes'] = '(Visi tipai)';
	$lang['strcreateaggregate'] = 'Kurti agregavimo funkciją';
	$lang['straggrbasetype'] = 'Pradinių duomenų tipas';
	$lang['straggrsfunc'] = 'Būsenos keitimo funkcija';
	$lang['straggrstype'] = 'Būsenos reikšmės duomenų tipas';
	$lang['straggrffunc'] = 'Galutinė funkcija';
	$lang['straggrinitcond'] = 'Pradinė sąlyga';
	$lang['straggrsortop'] = 'Rikiavimo operatorius';
	$lang['strconfdropaggregate'] = 'Ar tikrai norite šalinti agregavimo funkciją "%s"?';
	$lang['straggregatedropped'] = 'Agregavimo funkcija pašalinta.';
	$lang['straggregatedroppedbad'] = 'Nepavyko pašalinti agregavimo funkcijos.';
	$lang['straggraltered'] = 'Agregavimo funkcija pakeista.';
	$lang['straggralteredbad'] = 'Nepavyko pakeisti agregavimo funkcijos.';
	$lang['straggrneedsname'] = 'Turite suteikti agregavimo funkcijai pavadinimą.';
	$lang['straggrneedsbasetype'] = 'Turite nurodyti agregavimo funkcijos pradinių duomenų tipą.';
	$lang['straggrneedssfunc'] = 'Turite nurodyti agregavimo funkcijos būsenos keitimo funkcijos pavadinimą.';
	$lang['straggrneedsstype'] = 'Turite nurodyti agregavimo funkcijos būsenos reikšmės duomenų tipą.';
	$lang['straggrcreated'] = 'Agregavimo funkcija sukurta.';
	$lang['straggrcreatedbad'] = 'Nepavyko sukurti agregavimo funkcijos.';
	$lang['straggrshowall'] = 'Rodyti visas agregavimo funkcijas';

	// Operator Classes
	$lang['stropclasses'] = 'Operatorių klasės';
	$lang['strnoopclasses'] = 'Operatorių klasių nerasta.';
	$lang['straccessmethod'] = 'Prieigos metodas';

	// Stats and performance
	$lang['strrowperf'] = 'Įrašų Našumas';
	$lang['strioperf'] = 'I/O Našumas';
	$lang['stridxrowperf'] = 'Indeksų Įrašų Našumas';
	$lang['stridxioperf'] = 'Indeksų I/O Našumas';
	$lang['strpercent'] = '%';
	$lang['strsequential'] = 'Nuoseklus';
	$lang['strscan'] = 'Peržiūrėti';
	$lang['strread'] = 'Skaityti';
	$lang['strfetch'] = 'Paimti';
	$lang['strheap'] = 'Krūva';
$lang['strtoast'] = 'TOAST';
$lang['strtoastindex'] = 'TOAST Indeksas';
	$lang['strcache'] = 'Podėlis';
	$lang['strdisk'] = 'Diskas';
	$lang['strrows2'] = 'Įrašai';

	// Tablespaces
	$lang['strtablespace'] = 'Lentelių erdvė';
	$lang['strtablespaces'] = 'Lentelių erdvės';
	$lang['strshowalltablespaces'] = 'Rodyti visas lentelių erdves';
	$lang['strnotablespaces'] = 'Lentelių erdvių nerasta.';
	$lang['strcreatetablespace'] = 'Kurti lentelių erdvę';
	$lang['strlocation'] = 'Vieta';
	$lang['strtablespaceneedsname'] = 'Turite suteikti lentelių erdvei pavadinimą.';
	$lang['strtablespaceneedsloc'] = 'Turite nurodyti katalogą, kuriame turi būti sukurta lentelių erdvė.';
	$lang['strtablespacecreated'] = 'Lentelių erdvė sukurta.';
	$lang['strtablespacecreatedbad'] = 'Nepavyko sukurti lentelių erdvės.';
	$lang['strconfdroptablespace'] = 'Ar tikrai norite šalinti lentelių erdvę "%s"?';
	$lang['strtablespacedropped'] = 'Lentelių erdvė pašalinta.';
	$lang['strtablespacedroppedbad'] = 'Nepavyko pašalinti lentelių erdvės.';
	$lang['strtablespacealtered'] = 'Lentelių erdvė pakeista.';
	$lang['strtablespacealteredbad'] = 'Nepavyko pakeisti lentelių erdvės.';

	// Miscellaneous
	$lang['strtopbar'] = '%s veikia %s:%s -- Jūs esate prisijungęs kaip "%s"';
	$lang['strtimefmt'] = 'j M Y - g:iA';
	$lang['strhelp'] = 'Pagalba';
	$lang['strhelpicon'] = '?';
	$lang['strhelppagebrowser'] = 'Pagalbos puslapio naršyklė';
	$lang['strselecthelppage'] = 'Pasirinkite pagalbos puslapį';
	$lang['strinvalidhelppage'] = 'Netinkamas pagalbos puslapis.';
	$lang['strlogintitle'] = 'Prisijungti prie %s';
	$lang['strlogoutmsg'] = 'Atsijungta nuo %s';
	$lang['strloading'] = 'Įkeliama...';
	$lang['strerrorloading'] = 'Klaida įkeliant';
	$lang['strclicktoreload'] = 'Spustelėkite, kad būtų atsiųsta iš naujo';

	// Autovacuum
	$lang['strautovacuum'] = 'Automatinis apvalymas';
	$lang['strturnedon'] = 'Įjungta';
	$lang['strturnedoff'] = 'Išjungta';
	$lang['strenabled'] = 'Veiksnus';
	$lang['strnovacuumconf'] = 'Automatinio apvalymo konfigūracijų nerasta.';
	$lang['strvacuumbasethreshold'] = 'Apvalymo bazinė riba';
	$lang['strvacuumscalefactor'] = 'Apvalymo skalės koeficientas';
	$lang['stranalybasethreshold'] = 'Analizės bazinė riba';
	$lang['stranalyzescalefactor'] = 'Analizės skalės koeficientas';
$lang['strvacuumcostdelay'] = 'Apvalymo Cost Delay';
$lang['strvacuumcostlimit'] = 'Apvalymo Cost Limit';
	$lang['strvacuumpertable'] = 'Lentelių automatinio apvalymo konfigūracijos';
	$lang['straddvacuumtable'] = 'Pridėti lentelės automatinio apvalymo konfigūraciją';
	$lang['streditvacuumtable'] = 'Taisyti lentelės %s automatinio apvalymo konfigūraciją';
	$lang['strdelvacuumtable'] = 'Šalinti lentelės %s automatinio apvalymo konfigūraciją ?';
	$lang['strvacuumtablereset'] = 'Lentelės %s automatinio apvalymo konfigūracijos reikšmės atstatytos į numatytąsias';
	$lang['strdelvacuumtablefail'] = 'Nepavyko panaikinti lentelės %s automatinio apvalymo konfigūracijos';
	$lang['strsetvacuumtablesaved'] = 'Lentelės %s automatinio apvalymo konfigūracija įrašyta.';
	$lang['strsetvacuumtablefail'] = 'Nepavyko konfigūruoti lentelės %s automatinio apvalymo.';
	$lang['strspecifydelvacuumtable'] = 'Turite nurodyti lentelę, kurios automatinio apvalymo konfigūraciją norite panaikinti.';
	$lang['strspecifyeditvacuumtable'] = 'Turite nurodyti lentelę, kurios automatinio apvalymo konfigūraciją norite taisyti.';
	$lang['strnotdefaultinred'] = 'Reikšmės, kitokios nei numatytosios, pažymėtos raudonai.';

	// Table-level Locks
	$lang['strlocks'] = 'Blokuotės';
	$lang['strtransaction'] = 'Operacijos Identifikatorius';
	$lang['strvirtualtransaction'] = 'Virtualios Operacijos Identifikatorius';
	$lang['strprocessid'] = 'Proceso Identifikatorius';
	$lang['strmode'] = 'Blokuotės veiksena';
	$lang['strislockheld'] = 'Ar blokuotė veikia?';

	// Prepared transactions
	$lang['strpreparedxacts'] = 'Paruoštos operacijos';
	$lang['strxactid'] = 'Operacijos identifikatorius';
	$lang['strgid'] = 'Globalus identifikatorius';
	
	// Fulltext search
$lang['strfulltext'] = 'Full Text Search';
	$lang['strftsconfig'] = 'FTS konfigūracija';
	$lang['strftsconfigs'] = 'Konfigūracijos';
	$lang['strftscreateconfig'] = 'Kurti FTS konfigūraciją';
	$lang['strftscreatedict'] = 'Kurti žodyną';
	$lang['strftscreatedicttemplate'] = 'Kurti žodyno šabloną';
	$lang['strftscreateparser'] = 'Kurti analizatorių';
	$lang['strftsnoconfigs'] = 'FTS konfigūracijų nerasta.';
	$lang['strftsconfigdropped'] = 'FTS konfigūracija pašalinta.';
	$lang['strftsconfigdroppedbad'] = 'Nepavyko pašalinti FTS konfigūracijos.';
	$lang['strconfdropftsconfig'] = 'Ar tikrai norite šalinti FTS konfigūraciją "%s"?';
	$lang['strconfdropftsdict'] = 'Ar tikrai norite šalinti FTS žodyną "%s"?';
	$lang['strconfdropftsmapping'] = 'Ar tikrai norite šalinti atvaizdį "%s" FTS konfigūracijai "%s"?';
	$lang['strftstemplate'] = 'Šablonas';
	$lang['strftsparser'] = 'Analizatorius';
	$lang['strftsconfigneedsname'] = 'Turite suteikti FTS konfigūracijai pavadinimą.';
	$lang['strftsconfigcreated'] = 'FTS konfigūracija sukurta.';
	$lang['strftsconfigcreatedbad'] = 'Nepavyko sukurti FTS konfigūracijos.';
	$lang['strftsmapping'] = 'Atvaizdis';
	$lang['strftsdicts'] = 'Žodynai';
	$lang['strftsdict'] = 'Žodynas';
	$lang['strftsemptymap'] = 'Išvalyti FTS konfigūracijos atvaizdį.';
	$lang['strftsconfigaltered'] = 'FTS konfigūracija pakeista.';
	$lang['strftsconfigalteredbad'] = 'Nepavyko pakeisti FTS konfigūracijos.';
	$lang['strftsconfigmap'] = 'FTS konfigūracijos atvaizdis';
	$lang['strftsparsers'] = 'FTS analizatoriai';
	$lang['strftsnoparsers'] = 'FTS analizatorių nėra.';
	$lang['strftsnodicts'] = 'FTS žodynų nėra.';
	$lang['strftsdictcreated'] = 'FTS žodynas sukurtas.';
	$lang['strftsdictcreatedbad'] = 'Nepavyko sukurti FTS žodyno.';
$lang['strftslexize'] = 'Lexize';
$lang['strftsinit'] = 'Init';
	$lang['strftsoptionsvalues'] = 'Parinktys ir reikšmės';
	$lang['strftsdictneedsname'] = 'Turite suteikti FTS žodynui pavadinimą.';
	$lang['strftsdictdropped'] = 'FTS žodynas pašalintas.';
	$lang['strftsdictdroppedbad'] = 'Nepavyko pašalinti FTS žodyno.';
	$lang['strftsdictaltered'] = 'FTS žodynas pakeistas.';
	$lang['strftsdictalteredbad'] = 'Nepavyko pakeisti FTS žodyno.';
	$lang['strftsaddmapping'] = 'Pridėti naują atvaizdį';
	$lang['strftsspecifymappingtodrop'] = 'Turite nurodyti bent vieną atvaizdį, kurį norite pašalinti.';
	$lang['strftsspecifyconfigtoalter'] = 'Turite nurodyti bent vieną FTS konfigūraciją, kurią norite pakeisti.';
	$lang['strftsmappingdropped'] = 'FTS atvaizdis pašalintas.';
	$lang['strftsmappingdroppedbad'] = 'Nepavyko pašalinti FTS atvaizdžio.';
	$lang['strftsnodictionaries'] = 'Žodynų nerasta.';
	$lang['strftsmappingaltered'] = 'FTS atvaizdis pakeistas.';
	$lang['strftsmappingalteredbad'] = 'Nepavyko pakeisti FTS atvaizdžio.';
	$lang['strftsmappingadded'] = 'FTS atvaizdis pridėtas.';
	$lang['strftsmappingaddedbad'] = 'Nepavyko pridėti FTS atvaizdžio.';
	$lang['strftstabconfigs'] = 'Konfigūracijos';
	$lang['strftstabdicts'] = 'Žodynai';
	$lang['strftstabparsers'] = 'Analizatoriai';
	$lang['strftscantparsercopy'] = 'Negalima nurodyti kartu ir analizatoriaus, ir šablono, teksto paieškos konfikūracijos kūrimo metu.';
?>
