<?php
	/**
	 * Chinese language file.
	 */

	// Basic strings
	$plugin_lang['strplugindescription'] = 'Report plugin';
	$plugin_lang['strnoreportsdb'] = '您尚未建新報表資料庫，請參閱INSTALL檔說明。';

	// Reports
	$plugin_lang['strreport'] = '報表';
	$plugin_lang['strreports'] = '報表';
	$plugin_lang['strshowallreports'] = '顯示所有的報表';
	$plugin_lang['strnoreports'] = '找不到此報表。';
	$plugin_lang['strcreatereport'] = '建立新報表';
	$plugin_lang['strreportdropped'] = '成功刪除報表。';
	$plugin_lang['strreportdroppedbad'] = '刪除報表作業失敗。';
	$plugin_lang['strconfdropreport'] = '您確定要刪除報表 "%s"?';
	$plugin_lang['strreportneedsname'] = '您需為您的報表命名。';
	$plugin_lang['strreportneedsdef'] = '您需給您的報表 SQL。';
	$plugin_lang['strreportcreated'] = '成功儲存報表。';
	$plugin_lang['strreportcreatedbad'] = '無法儲存報表。';
?>
