<?php
	/**
	 * Lithuanian language file.
	 */ 

	// Basic
	$plugin_lang['strplugindescription'] = 'Report plugin';
	$plugin_lang['strnoreportsdb'] = 'Jūs nesate sukūrę ataskaitų duomenų bazės. Instrukcijas skaitykite INSTALL faile.';

	// Reports
	$plugin_lang['strreport'] = 'Ataskaita';
	$plugin_lang['strreports'] = 'Ataskaitos';
	$plugin_lang['strshowallreports'] = 'Rodyti visas ataskaitas';
	$plugin_lang['strnoreports'] = 'Ataskaitų nerasta.';
	$plugin_lang['strcreatereport'] = 'Kurti ataskaitą';
	$plugin_lang['strreportdropped'] = 'Ataskaita pašalinta.';
	$plugin_lang['strreportdroppedbad'] = 'Nepavyko pašalinti ataskaitos.';
	$plugin_lang['strconfdropreport'] = 'Ar tikrai norite šalinti ataskaitą "%s"?';
	$plugin_lang['strreportneedsname'] = 'Turite suteikti ataskaitai pavadinimą.';
	$plugin_lang['strreportneedsdef'] = 'Turite pateikti ataskaitos SQL apibrėžtį.';
	$plugin_lang['strreportcreated'] = 'Ataskaita įrašyta.';
	$plugin_lang['strreportcreatedbad'] = 'Nepavyko įrašyti ataskaitos.';
?>
