<?php
    /**
     * Spanish language file.
     */

	// Basic
	$plugin_lang['strplugindescription'] = 'Report plugin';
	$plugin_lang['strnoreportsdb'] = 'Aún no se ha creado  la base de datos para los reportes. Lea las instrucciones del archivo INSTALL.';

	// Reports
	$plugin_lang['strreport'] = 'Reporte';
	$plugin_lang['strreports'] = 'Reportes';
	$plugin_lang['strshowallreports'] = 'Mostrar todos los reportes';
	$plugin_lang['strnoreports'] = 'No se encontró el reporte.';
	$plugin_lang['strcreatereport'] = 'Crear Reporte';
	$plugin_lang['strreportdropped'] = 'Reporte eliminado.';
	$plugin_lang['strreportdroppedbad'] = 'Falló al eliminar el Reporte.';
	$plugin_lang['strconfdropreport'] = '¿Estás seguro que quiere eliminar el reporte "%s"?';
	$plugin_lang['strreportneedsname'] = 'Debe especificar un nombre para el reporte.';
	$plugin_lang['strreportneedsdef'] = 'Debe especificar un SQL para el reporte.';
	$plugin_lang['strreportcreated'] = 'Reporte guardado.';
	$plugin_lang['strreportcreatedbad'] = 'Falló al guardar el reporte.';
?>
