<?php
// by "El-Shamaa, Khaled" <k.el-shamaa#cgiar.org>
$ADODB_LANG_ARRAY = array (
			'LANG'			    => 'ar',
	    DB_ERROR			=> 'خطأ غير محدد',
	    DB_ERROR_ALREADY_EXISTS	=> 'موجود مسبقا',
	    DB_ERROR_CANNOT_CREATE	=> 'لا يمكن إنشاء',
	    DB_ERROR_CANNOT_DELETE	=> 'لا يمكن حذف',
	    DB_ERROR_CANNOT_DROP	=> 'لا يمكن حذف',
	    DB_ERROR_CONSTRAINT 	=> 'عملية إدخال ممنوعة',
	    DB_ERROR_DIVZERO		=> 'عملية التقسيم على صفر',
	    DB_ERROR_INVALID		=> 'غير صحيح',
	    DB_ERROR_INVALID_DATE	=> 'صيغة وقت أو تاريخ غير صحيحة',
	    DB_ERROR_INVALID_NUMBER	=> 'صيغة رقم غير صحيحة',
	    DB_ERROR_MISMATCH		=> 'غير متطابق',
	    DB_ERROR_NODBSELECTED	=> 'لم يتم إختيار قاعدة البيانات بعد',
	    DB_ERROR_NOSUCHFIELD	=> 'ليس هنالك حقل بهذا الاسم',
	    DB_ERROR_NOSUCHTABLE	=> 'ليس هنالك جدول بهذا الاسم',
	    DB_ERROR_NOT_CAPABLE	=> 'قاعدة البيانات المرتبط بها غير قادرة',
	    DB_ERROR_NOT_FOUND		=> 'لم يتم إيجاده',
	    DB_ERROR_NOT_LOCKED 	=> 'غير مقفول',
	    DB_ERROR_SYNTAX		=> 'خطأ في الصيغة',
	    DB_ERROR_UNSUPPORTED	=> 'غير مدعوم',
	    DB_ERROR_VALUE_COUNT_ON_ROW => 'عدد القيم في السجل',
	    DB_ERROR_INVALID_DSN	=> 'DSN غير صحيح',
	    DB_ERROR_CONNECT_FAILED	=> 'فشل عملية الإتصال',
	    0			       => 'ليس هنالك أخطاء', // DB_OK
	    DB_ERROR_NEED_MORE_DATA	=> 'البيانات المزودة غير كافية',
	    DB_ERROR_EXTENSION_NOT_FOUND=> 'لم يتم إيجاد الإضافة المتعلقة',
	    DB_ERROR_NOSUCHDB		=> 'ليس هنالك قاعدة بيانات بهذا الاسم',
	    DB_ERROR_ACCESS_VIOLATION	=> 'سماحيات غير كافية'
);
?>