<?php
// Catalan language
// contributed by "Josep Lladonosa" jlladono#pie.xtec.es
$ADODB_LANG_ARRAY = array (
			'LANG'                      => 'ca',
            DB_ERROR                    => 'error desconegut',
            DB_ERROR_ALREADY_EXISTS     => 'ja existeix',
            DB_ERROR_CANNOT_CREATE      => 'no es pot crear',
            DB_ERROR_CANNOT_DELETE      => 'no es pot esborrar',
            DB_ERROR_CANNOT_DROP        => 'no es pot eliminar',
            DB_ERROR_CONSTRAINT         => 'violació de constraint',
            DB_ERROR_DIVZERO            => 'divisió per zero',
            DB_ERROR_INVALID            => 'no és vàlid',
            DB_ERROR_INVALID_DATE       => 'la data o l\'hora no són vàlides',
            DB_ERROR_INVALID_NUMBER     => 'el nombre no és vàlid',
            DB_ERROR_MISMATCH           => 'no hi ha coincidència',
            DB_ERROR_NODBSELECTED       => 'cap base de dades seleccionada',
            DB_ERROR_NOSUCHFIELD        => 'camp inexistent',
            DB_ERROR_NOSUCHTABLE        => 'taula inexistent',
            DB_ERROR_NOT_CAPABLE        => 'l\'execució secundària de DB no pot',
            DB_ERROR_NOT_FOUND          => 'no trobat',
            DB_ERROR_NOT_LOCKED         => 'no blocat',
            DB_ERROR_SYNTAX             => 'error de sintaxi',
            DB_ERROR_UNSUPPORTED        => 'no suportat',
            DB_ERROR_VALUE_COUNT_ON_ROW => 'el nombre de columnes no coincideix amb el nombre de valors en la fila',
            DB_ERROR_INVALID_DSN        => 'el DSN no és vàlid',
            DB_ERROR_CONNECT_FAILED     => 'connexió fallida',
            0	                       => 'cap error', // DB_OK
            DB_ERROR_NEED_MORE_DATA     => 'les dades subministrades són insuficients',
            DB_ERROR_EXTENSION_NOT_FOUND=> 'extensió no trobada',
            DB_ERROR_NOSUCHDB           => 'base de dades inexistent',
            DB_ERROR_ACCESS_VIOLATION   => 'permisos insuficients'
);
?>