<?php

	/**
	 * Turkish language file for phpPgAdmin.  Use this as a basis
	 * for new translations.
	 *
	 * $Id: turkish.php,v 1.15 2007/04/24 11:42:07 soranzo Exp $
	 */

	// Language and character set
	$lang['applang'] = 'Türkçe';
	$lang['applocale'] = 'tr-TR';
	$lang['applangdir'] = 'ltr';

	// Basic strings
	$lang['strintro'] = 'phpPgAdmin\'e hoşgeldiniz.';
	$lang['strppahome'] = 'phpPgAdmin Ana Sayfası';
	$lang['strpgsqlhome']  =  'PostgreSQL Ana Sayfası';
	$lang['strpgsqlhome_url'] = 'http://www.postgresql.org/';
	$lang['strlocaldocs'] = 'PostgreSQL Belgeleri (yerel)';
	$lang['strreportbug'] = 'Hata Bildirin';
	$lang['strviewfaq'] = 'Sıkça Sorulan Sorular';
	$lang['strviewfaq_url'] = 'http://phppgadmin.sourceforge.net/doku.php?id=faq';
	
	// Basic strings
	$lang['strlogin']  =  'Giriş';
	$lang['strloginfailed'] = 'Giriş Başarısız';
	$lang['strlogindisallowed']  =  'Güvenlik nedeniyle girişe izin verilmedi.';
	$lang['strserver'] = 'Sunucu';
	$lang['strservers']  =  'Sunucular';
	$lang['strintroduction']  =  'Giriş';
	$lang['strhost']  =  'Sunucu';
	$lang['strport']  =  'Port';
	$lang['strlogout'] = 'Çıkış';
	$lang['strowner'] = 'Sahibi';
	$lang['straction'] = 'Eylem';
	$lang['stractions'] = 'Eylemler';
	$lang['strname'] = 'Ad';
	$lang['strdefinition'] = 'Tanım';
	$lang['strproperties'] = 'Özellikler';
	$lang['strbrowse'] = 'Gözat';
	$lang['strdrop'] = 'Sil';
	$lang['strdropped'] = 'Silindi';
	$lang['strnull'] = 'Null';
	$lang['strnotnull'] = 'Null/Null değil';
	$lang['strprev'] = 'Önceki';
	$lang['strnext'] = 'Sonraki';
	$lang['strfirst'] = '<< İlk';
	$lang['strlast'] = 'Son >>';
	$lang['strfailed']  =  'Başarısız oldu.';
	$lang['strcreate']  =  'Yarat';
	$lang['strcreated'] = 'Yaratıldı';
	$lang['strcomment'] = 'Yorum';
	$lang['strlength'] = 'Uzunluk';
	$lang['strdefault'] = 'Ön tanımlı değer';
	$lang['stralter'] = 'Değiştir';
	$lang['strok'] = 'Tamam';
	$lang['strcancel'] = 'İptal Et';
	$lang['strsave'] = 'Kaydet';
	$lang['strreset'] = 'Temizle';
	$lang['strinsert'] = 'Ekle';
	$lang['strselect'] = 'Seç';
	$lang['strdelete'] = 'Sil';
	$lang['strupdate'] = 'Güncelle';
	$lang['strreferences'] = 'References';
	$lang['stryes'] = 'Evet';
	$lang['strno'] = 'Hayır';
	$lang['strtrue']  =  'TRUE';
	$lang['strfalse']  =  'FALSE';
	$lang['stredit'] = 'Düzenle';
	$lang['strcolumn']  =  'KolonF';
	$lang['strcolumns'] = 'Kolonlar';
	$lang['strrows'] = 'satır';
	$lang['strrowsaff']  =  'satır işlendi.';
	$lang['strobjects']  =  'nesne(ler)';
	$lang['strback'] = 'Geri';
	$lang['strqueryresults'] = 'Sorgu sonuçları';
	$lang['strshow'] = 'Göster';
	$lang['strempty'] = 'Boşalt';
	$lang['strlanguage'] = 'Dil';
	$lang['strencoding'] = 'Karakter kodlaması';
	$lang['strvalue'] = 'Değer';
	$lang['strunique'] = 'Tekil';
	$lang['strprimary'] = 'Birincil';
	$lang['strexport'] = 'Export';
	$lang['strimport']  =  'Import';
	$lang['strallowednulls']  =  'İzin verilen NULL karakterler';
	$lang['strbackslashn']  =  '\N';
	$lang['strnull']  =  'Null';
	$lang['strnull']  =  'NULL (sözcük)';
	$lang['stremptystring']  =  'Boş metin/alan';
	$lang['strsql'] = 'SQL';
	$lang['stradmin'] = 'Yönetici';
	$lang['strvacuum'] = 'Vacuum';
	$lang['stranalyze'] = 'Analyze';
	$lang['strclusterindex'] = 'Cluster';
	$lang['strclustered']  =  'Cluster edildi mi?';
	$lang['strreindex'] = 'Reindex';
	$lang['strrun'] = 'Çalıştır';
	$lang['stradd'] = 'Ekle';
	$lang['strremove']  =  'Kaldır';
	$lang['strevent'] = 'Event';
	$lang['strwhere'] = 'Where';
	$lang['strinstead'] = 'Do Instead';
	$lang['strwhen'] = 'When';
	$lang['strformat'] = 'Format';
	$lang['strdata'] = 'Veri';
	$lang['strconfirm'] = 'Onayla';
	$lang['strexpression'] = 'İfade';
	$lang['strellipsis'] = '...';
	$lang['strseparator']  =  ': ';
	$lang['strexpand'] = 'Genişlet';
	$lang['strcollapse']  =  'Dar görünüm';
	$lang['strexplain'] = 'Explain';
	$lang['strexplainanalyze']  =  'Explain Analyze';
	$lang['strfind'] = 'Bul';
	$lang['stroptions'] = 'Seçenekler';
	$lang['strrefresh'] = 'Yenile';
	$lang['strdownload'] = 'İndir';
	$lang['strdownloadgzipped']  =  'gzip ile sıkıştırılmış halde indir';
	$lang['strinfo']  =  'Bilgi';
	$lang['stroids']  =  'OIDler';
	$lang['stradvanced']  =  'Gelişmiş';
	$lang['strvariables']  =  'Değişkenler';
	$lang['strprocess']  =  'Süreç';
	$lang['strprocesses']  =  'Süreçler';
	$lang['strsetting']  =  'Ayar';
	$lang['streditsql']  =  'SQL Düzenle';
	$lang['strruntime']  =  'Toplam çalışma süresi: %s ms';
	$lang['strpaginate']  =  'Sonuçları sayfalandır.';
	$lang['struploadscript']  =  'ya da bir SQL betiği yükleyin:';
	$lang['strstarttime']  =  'Başlangıç zamanı';
	$lang['strfile']  =  'Dosya';
	$lang['strfileimported']  =  'Dosya import edildi.';
	$lang['strtrycred']  =  'Giriş bilgilerini tüm sunucular için kullan';
$lang['strexecute']  =  'Execute';

	// Error handling
	$lang['strnoframes']  =  'Bu uygulama en iyi olarak frame destekli bir tarayıcı ile kullanılabilir; ancak frameler ile kullanmak istemiyorsanız aşağıdaki linke tıklayabilirsiniz.';
	$lang['strnoframeslink']  =  'Frame olmadan kullan';
	$lang['strbadconfig'] = 'config.inc.php dosyaniz güncel değil. Bu dosyayı yeni config.inc.php-dist dosyasından yaratmanız gerekmektedir.';
	$lang['strnotloaded'] = 'PHP kurulumunuzda PostgreSQL desteği bulunamamıştır.';
        $lang['strpostgresqlversionnotsupported'] = 'Bu PostgreSQL sürümü desteklenmemektedir. Lütfen %s ya da üstü bir sürüme güncelleyiniz.';
	$lang['strbadschema'] = 'Geçersiz şema.';
	$lang['strbadencoding'] = 'İstemci dil kodlamasını ayarlamaya çalışırken bir hata oluştu.';
	$lang['strsqlerror'] = 'SQL hatası:';
	$lang['strinstatement'] = 'Üstteki hata, aşağıdaki ifade içinde oluştu:';
	$lang['strinvalidparam'] = 'Geçersiz betik parametreleri.';
	$lang['strnodata'] = 'Satır bulunamadı.';
	$lang['strnoobjects']  =  'Hiçbir nesne bulunamadı..';
	$lang['strrownotunique']  =  'Bu satır için hiçbir tekil belirtici bulunamadı.';
	$lang['strnouploads']  =  'Dosya yükleme özelliği etkin değil.';
	$lang['strimporterror']  =  'Import hatası.';
	$lang['strimporterror-fileformat']  =  'Import hatası: Dosya tipi otomatik olarak belirlenemedi.';
	$lang['strimporterrorline']  =  '%s numaralı satırda import hatası.';
$lang['strimporterrorline-badcolumnnum']  =  'Import error on line %s:  Line does not possess the correct number of columns.';
$lang['strimporterror-uploadedfile']  =  'Import error: File could not be uploaded to the server';
$lang['strcannotdumponwindows']  =  'Dumping of complex table and schema names on Windows is not supported.';

	// Tables
	$lang['strtable'] = 'Tablo';
	$lang['strtables'] = 'Tablolar';
	$lang['strshowalltables'] = 'Tüm tabloları göster';
	$lang['strnotables'] = 'Veritabanında tablo bulunamadı.';
	$lang['strnotable'] = 'Veritabanında tablo bulunamadı.';
	$lang['strcreatetable'] = 'Yeni tablo yarat';
	$lang['strtablename'] = 'Tablo adı';
	$lang['strtableneedsname'] = 'Tablonuza bir ad vermeniz gerekmektedir.';
	$lang['strtableneedsfield'] = 'En az bir alan belirtmeniz gerekmektedir.';
	$lang['strtableneedscols'] = 'Geçerli miktarda kolon sayısı belirtmeniz gerekmektedir.';
	$lang['strtablecreated'] = 'Tablo yaratıldı.';
	$lang['strtablecreatedbad'] = 'Tablo yaratılamadı.';
	$lang['strconfdroptable'] = '"%s" tablosunu kaldırmak istediğinizden emin misiniz?';
	$lang['strtabledropped'] = 'Tablo kaldırıldı.';
	$lang['strtabledroppedbad'] = 'Tablo kaldırılamadı.';
	$lang['strconfemptytable'] = '"%s" tablosunu boşaltmak istediğinizden emin misiniz?';
	$lang['strtableemptied'] = 'Tablo boşaltıldı.';
	$lang['strtableemptiedbad'] = 'Tablo boşaltılamadı.';
	$lang['strinsertrow'] = 'Yeni kayıt gir';
	$lang['strrowinserted'] = 'Yeni kayıt girildi.';
	$lang['strrowinsertedbad'] = 'Yeni kayıt girme işlemi başarısız oldu.';
	$lang['strrowduplicate']  =  'Satır ekleme başarısız oldu, birbirinin aynı iki kayıt girilmek istendi.';
	$lang['streditrow'] = 'Kayıdın içeriğini değiştir.';
	$lang['strrowupdated'] = 'Kayıt güncellendi.';
	$lang['strrowupdatedbad'] = 'Kayıt güncelleme işleme başarısız oldu.';
	$lang['strdeleterow'] = 'Kaydı sil';
	$lang['strconfdeleterow'] = 'Bu kaydı silmek istediğinize emin misiniz?';
	$lang['strrowdeleted'] = 'Kayıt silindi.';
	$lang['strrowdeletedbad'] = 'Kayıt silinme işlemi başarısız oldu.';
        $lang['strinsertandrepeat'] = 'Ekle ve Tekrarla';
        $lang['strnumcols'] = 'Kolon sayısı';
        $lang['strcolneedsname'] = 'Kolon için bir ad vermelisiniz.';
	$lang['strselectallfields']  =  'Tüm alanları seç';
	$lang['strselectneedscol'] = 'En az bir kolon işaretlemelisiniz';
	$lang['strselectunary']  =  'Unary operatörlerin değeri olamaz.';
	$lang['straltercolumn'] = 'Kolonu değiştir (alter)';
	$lang['strcolumnaltered'] = 'Kolon değiştirildi (alter)';
	$lang['strcolumnalteredbad'] = 'Kolon değiştirilme işlemi başarısız oldu.';
	$lang['strconfdropcolumn']  =  '"%s" kolonunu "%s" tablosundan silmek istediğinize emin misiniz?';
	$lang['strcolumndropped'] = 'Kolon silindi.';
	$lang['strcolumndroppedbad'] = 'Kolon silme işlemi başarısız oldu.';
	$lang['straddcolumn'] = 'Yeni kolon ekle';
	$lang['strcolumnadded'] = 'Kolon eklendi.';
	$lang['strcolumnaddedbad'] = 'Kolon eklenemedi.';
	$lang['strcascade']  =  'CASCADE';
	$lang['strtablealtered'] = 'Tablo alter edildi..';
	$lang['strtablealteredbad'] = 'Tablo alteration işlemi başarısız oldu.';
	$lang['strdataonly']  =  'Sadece veri';
	$lang['strstructureonly']  =  'Sadece yapı';
	$lang['strstructureanddata']  =  'Yapı ve veri';
	$lang['strtabbed']  =  'Tabbed';
	$lang['strauto']  =  'Otomatik';
	$lang['strconfvacuumtable'] = '"%s" tablosunu vakumlamak istediğiniz emin misiniz?';
        $lang['strestimatedrowcount'] = 'Yaklaşık satır sayısı';

	// Users
	$lang['struser'] = 'Kullanıcı';
	$lang['strusers'] = 'Kullanıcılar';
	$lang['strusername'] = 'Kullanıcı Adı';
	$lang['strpassword'] = 'Şifresi';
	$lang['strsuper'] = 'Superuser mı?';
	$lang['strcreatedb'] = 'Veritabanı yaratabilsin mi?';
	$lang['strexpires'] = 'Expires';
	$lang['strsessiondefaults']  =  'Oturum varsayılanları';
	$lang['strnousers']  =  'Hiçbir kullanıcı bulunamadı.';
        $lang['struserupdated'] = 'Kullanıcı güncellendi.';
	$lang['struserupdatedbad'] = 'Kullanıcı güncelleme işlemi başarısız oldu.';
	$lang['strshowallusers'] = 'Tüm kullanıcıları göster.';
	$lang['strcreateuser'] = 'Yeni kullanıcı yarat';
	$lang['struserneedsname']  =  'Kullanıcınız için bir ad vermelisiniz.';
	$lang['strusercreated'] = 'Kullanıcı yaratıldı.';
	$lang['strusercreatedbad'] = 'Kullanıcı yaratılma işlemi başarısız oldu.';
	$lang['strconfdropuser'] = '"%s" kullanıcısını silmek istediğinize emin misiniz?';
	$lang['struserdropped'] = 'Kullanıcı silindi.';
	$lang['struserdroppedbad'] = 'Kullanıcı silme işlemi başarısız oldu.';
	$lang['straccount'] = 'Hesap';
	$lang['strchangepassword'] = 'Şifre Değiştir';
	$lang['strpasswordchanged'] = 'Şifre değiştirildi.';
	$lang['strpasswordchangedbad'] = 'Şifre değiştirme başarısız oldu.';
	$lang['strpasswordshort']  =  'Şifre çok kısa.';
	$lang['strpasswordconfirm'] = 'Şifreler uyuşmadı.';
	
	// Groups
	$lang['strgroup'] = 'Grup';
	$lang['strgroups'] = 'Gruplar';
	$lang['strnogroup'] = 'Grup bulunamadı.';
	$lang['strnogroups'] = 'Grup bulunamadı.';
	$lang['strcreategroup'] = 'Yeni grup yarat';
	$lang['strshowallgroups'] = 'Tüm grupları göster';
	$lang['strgroupneedsname'] = 'Grup yaratabilmek için bir ad vermelisiniz.';
	$lang['strgroupcreated'] = 'Grup yaratıldı.';
	$lang['strgroupcreatedbad'] = 'Grup yaratma işlemi başarısız oldu.';	
	$lang['strconfdropgroup'] = '"%s" grubunu silmek istediğinize emin misiniz?';
	$lang['strgroupdropped'] = 'Grup silindi.';
	$lang['strgroupdroppedbad'] = 'Grup silme işlemi başarısız oldu.';
	$lang['strmembers'] = 'Üyeler';
	$lang['straddmember'] = 'Üye ekle';
	$lang['strmemberadded'] = 'Üye eklendi.';
	$lang['strmemberaddedbad'] = 'Üye ekleme başarısız oldu.';
	$lang['strdropmember'] = 'Üyeyi kaldır';
	$lang['strconfdropmember'] = '"%s" üyesini "%s" grubundan silmek istediğinize emin misiniz?';
	$lang['strmemberdropped'] = 'Üye silindi.';
	$lang['strmemberdroppedbad'] = 'Üye silme başarısız oldu.';

	// Privilges
	$lang['strprivilege'] = 'İzni';
	$lang['strprivileges'] = 'İzinler';
	$lang['strnoprivileges'] = 'Bu nesnenin bir izni yoktur.';
	$lang['strgrant'] = 'İzni ver';
	$lang['strrevoke'] = 'İzni kaldır';
	$lang['strgranted'] = 'İzimler verildi.';
	$lang['strgrantfailed'] = 'İzinlerin grant işlemi başarısız oldu.';

	$lang['strgrantbad'] = 'En az bir kullanıcı ya da grup ve en az bir izin belirtmelisiniz.';
	$lang['strgrantor'] = 'Grantor';
	$lang['strasterisk'] = '*';

	// Databases
	$lang['strdatabase'] = 'Veritabanı';
	$lang['strdatabases'] = 'Veritabanları';
	$lang['strshowalldatabases'] = 'Tüm veritabanlarını göster';
	$lang['strnodatabase'] = 'Veritabanı bulunamadı.';
	$lang['strnodatabases'] = 'Veritabanı bulunamadı.';
	$lang['strcreatedatabase'] = 'Veritabanı yarat';
	$lang['strdatabasename'] = 'Veritabanı adı';
	$lang['strdatabaseneedsname'] = 'Veritabanınıza bir ad vermelisiniz.';
	$lang['strdatabasecreated'] = 'Veritabanı yaratıldı.';
	$lang['strdatabasecreatedbad'] = 'Veritabanı yaratılamadı.';	
	$lang['strconfdropdatabase'] = '"%s" veritabanını kaldırmak istediğinize emin misiniz?';
	$lang['strdatabasedropped'] = 'Veritabanı kaldırıldı.';
	$lang['strdatabasedroppedbad'] = 'Veritabanı kaldırma başarısız oldu.';
	$lang['strentersql'] = 'Veritabanı üzerinde çalıştırılacak sorgu/sorguları aşağıya yazınız:';
	$lang['strsqlexecuted'] = 'SQL çalıştırıldı.';
	$lang['strvacuumgood']  =  'Vacuum tamamlandı.';
	$lang['strvacuumbad'] = 'Vacuum işlemi başarısız oldu.';
	$lang['stranalyzegood'] = 'Analyze işlemi tamamlandı.';
	$lang['stranalyzebad'] = 'Analyze işlemi başarısız oldu.';
	$lang['strreindexgood']  =  'Reindex tamamlandı.';
	$lang['strreindexbad']  =  'Reindex başarısız oldu.';
	$lang['strfull']  =  'Full';
	$lang['strfreeze']  =  'Freeze';
	$lang['strforce']  =  'Force';
	$lang['strsignalsent'] = 'Sinyal gönderildi.';
        $lang['strsignalsentbad'] = 'Sinyal gönderme işlemi başarısız oldu';
        $lang['strallobjects'] = 'Tüm nesneler';
	$lang['strdatabasealtered']  =  'Veritabanı değiştirildi.';
	$lang['strdatabasealteredbad']  =  'Veritabanı değiştirme başarısız oldu.';

	// Views
	$lang['strview'] = 'View';
	$lang['strviews'] = 'Viewlar';
	$lang['strshowallviews'] = 'Tüm viewları göster';
	$lang['strnoview'] = 'Bir view bulunamadı.';
	$lang['strnoviews'] = 'Bir view bulunamadı.';
	$lang['strcreateview'] = 'View yarat';
	$lang['strviewname'] = 'View adı';
	$lang['strviewneedsname'] = 'View için bir ad belirtmelisiniz.';
	$lang['strviewneedsdef'] = 'View için bir tanım belirtmelisiniz.';
	$lang['strviewneedsfields']  =  'View içinde görünmesini istediğiniz kolonları belirtmelisiniz.';
 	$lang['strviewcreated'] = 'View yaratıldı.';
	$lang['strviewcreatedbad'] = 'View yaratma işlemi başarısız oldu.';
	$lang['strconfdropview'] = '"%s" viewini kaldırmak istediğinize emin misiniz?';
	$lang['strviewdropped'] = 'View kaldırıldı.';
	$lang['strviewdroppedbad'] = 'View kaldırma işlemi başarısız oldu.';
	$lang['strviewupdated'] = 'View güncellendi.';
	$lang['strviewupdatedbad'] = 'View güncelleme işlemi başarısız oldu.';
	$lang['strviewlink']  =  'Linking Keys';
	$lang['strviewconditions']  =  'Ek durumlar';
	$lang['strcreateviewwiz']  =  'Sihirbaz ile view yaratın';

	// Sequences
	$lang['strsequence'] = 'Sequence';
	$lang['strsequences'] = 'Sequences';
	$lang['strshowallsequences'] = 'Show all sequences';
	$lang['strnosequence'] = 'No sequence found.';
	$lang['strnosequences'] = 'No sequences found.';
	$lang['strcreatesequence'] = 'Create sequence';
	$lang['strlastvalue'] = 'Son değer';
	$lang['strincrementby'] = 'Arttırma değeri';	
	$lang['strstartvalue'] = 'Başlangıç Değeri';
	$lang['strmaxvalue'] = 'Max Değer';
	$lang['strminvalue'] = 'Min Değer';
	$lang['strcachevalue'] = 'Cache Değeri';
	$lang['strlogcount'] = 'Log Count';
	$lang['striscycled'] = 'Is Cycled?';
	$lang['strsequenceneedsname'] = 'Sequence için bir ad belirtmelisiniz.';
	$lang['strsequencecreated'] = 'Sequence yaratıldı.';
	$lang['strsequencecreatedbad'] = 'Sequence yaratma işlemi başarısız oldu.'; 
	$lang['strconfdropsequence'] = '"%s" sequence ini kaldırmak istediğinize emin misiniz?';
	$lang['strsequencedropped'] = 'Sequence kaldırıldı.';
	$lang['strsequencedroppedbad'] = 'Sequence kaldırma işlemi başarısız oldu.';
	$lang['strsequencereset'] = 'Sequence sıfırlandı.';
	$lang['strsequenceresetbad'] = 'Sequence sıfırlama başarısız oldu.';

	// Indexes
	$lang['strindex']  =  'Index';
	$lang['strindexes'] = 'Indeksler';
	$lang['strindexname'] = 'Indeks adı';
	$lang['strshowallindexes'] = 'Tüm indeksleri göster';
	$lang['strnoindex'] = 'Hiçbir indeks bulunamadı.';
	$lang['strnoindexes'] = 'Hiçbir indeks bulunamadı.';
	$lang['strcreateindex'] = 'Indeks yarat';
	$lang['strtabname'] = 'Tab Adı';
	$lang['strcolumnname'] = 'Kolon adı';
	$lang['strindexneedsname'] = 'Indeksinize bir ad vermeniz gerekmektedir.';
	$lang['strindexneedscols'] = 'Geçerli kolın sayısı vermeniz gerekmektedir.';
	$lang['strindexcreated'] = 'Indeks yaratıldı.';
	$lang['strindexcreatedbad'] = 'Index creation failed.';
	$lang['strconfdropindex'] = '"%s" indeksini kaldırmak istediğinize emin misiniz?';
	$lang['strindexdropped'] = 'Indeks kaldırıldı.';
	$lang['strindexdroppedbad'] = 'Indeks kaldırılamadı.';
	$lang['strkeyname'] = 'Anahtar adı';
	$lang['struniquekey'] = 'Tekil (Unique) Anahtar';
	$lang['strprimarykey'] = 'Birincil Anahtar (Primary Key)';
 	$lang['strindextype'] = 'Indeksin tipi';
	$lang['strtablecolumnlist'] = 'Tablodaki kolonlar';
	$lang['strindexcolumnlist'] = 'Indeksteki kolonlar';
	$lang['strconfcluster']  =  '"%s" tablosunu cluster etmek istiyor musunuz?';
	$lang['strclusteredgood']  =  'Cluster tamamlandı.';
	$lang['strclusteredbad']  =  'Cluster başarısız oldu.';
	$lang['strcluster']  =  'Küme';

	// Rules
	$lang['strrules'] = 'Rules';
	$lang['strrule'] = 'Rule';
	$lang['strshowallrules'] = 'Show all Rules';
	$lang['strnorule'] = 'Rule bulunamadı.';
	$lang['strnorules'] = 'Rule bulunamadı.';
	$lang['strcreaterule'] = 'Rule yarat';
	$lang['strrulename'] = 'Rule adı';
	$lang['strruleneedsname'] = 'Rule için bir ad belirtmelisiniz.';
	$lang['strrulecreated'] = 'Rule yaratıldı.';
	$lang['strrulecreatedbad'] = 'Rule yaratma işlemi başarısız oldu.';
	$lang['strconfdroprule'] = '"%s" kuralını "%s" tablosundan silmek istediğinize emin misiniz?';
	$lang['strruledropped'] = 'Rule silindi';
	$lang['strruledroppedbad'] = 'Rule silinme işlemi başarısız oldu.';

	// Constraints
	$lang['strconstraint']  =  'Kısıtlama';
	$lang['strconstraints'] = 'Kısıtlamalar';
	$lang['strshowallconstraints'] = 'Tüm kısıtlamaları (constraint) göster.';
	$lang['strnoconstraints'] = 'Hiçbir kısıtlama (constraint) bulunamadı.';
	$lang['strcreateconstraint'] = 'Kısıtlama (Constraint) yarat';
	$lang['strconstraintcreated'] = 'Kısıtlama (Constraint) yaratıldı.';
	$lang['strconstraintcreatedbad'] = 'Kısıtlama (Constraint) yaratma işlemi başarısız oldu.';
	$lang['strconfdropconstraint'] = '"%s" üzerindeki "%s" kısıtlamasını (constraint) kaldırmak istiyor musunuz?';
	$lang['strconstraintdropped'] = 'Kısıtlama (Constraint) kaldırıldı';
	$lang['strconstraintdroppedbad'] = 'Kısıtlama (Constraint) işlemi başarısız oldu.';
	$lang['straddcheck'] = 'Kontrol (Check) ekle';
	$lang['strcheckneedsdefinition'] = 'Kontrol (Check) kısıtlaması (constraint) için bir tanım girilmelidir.';
	$lang['strcheckadded'] = 'Kontrol kısıtlaması (Check constraint) eklendi.';
	$lang['strcheckaddedbad'] = 'Kontrol kısıtlaması (Check constraint) ekleme işlemi başarısız oldu.';
	$lang['straddpk'] = 'Birincil Anahtar Ekle';
	$lang['strpkneedscols'] = 'Birincil anahtar için en az bir kolon gereklidir.';
	$lang['strpkadded'] = 'Birincil anahtar eklendi.';
	$lang['strpkaddedbad'] = 'Birincil anahtar eklenemedi.';
	$lang['stradduniq'] = 'Tekil (Unique) anahtar ekle';
	$lang['struniqneedscols'] = 'Tekil anahtar yaratmak için en az bir kolon gerekir.';
	$lang['struniqadded'] = 'Tekil anahtar eklendi.';
	$lang['struniqaddedbad'] = 'Tekil anahtar eklenemedi.';
	$lang['straddfk'] = 'İkincil anahtar ekle';
	$lang['strfkneedscols'] = 'İkincil anahtar yaratmak için en az bir kolon gerekir.';
	$lang['strfkneedstarget'] = 'İkincil anahtar hedef bir tablo gerektirir.';
	$lang['strfkadded']  =  'İkincil anahtar eklendi.';
	$lang['strfkaddedbad'] = 'İkincil anahtar eklenemedi.';
	$lang['strfktarget'] = 'Hedef tablo';

	$lang['strfkcolumnlist'] = 'Anahtardaki kolonlar';
	$lang['strondelete'] = 'ON DELETE';
	$lang['stronupdate'] = 'ON UPDATE';
	// Functions
	$lang['strfunction'] = 'Fonksiyon';
	$lang['strfunctions'] = 'Fonksiyonlar';
	$lang['strshowallfunctions'] = 'Tüm fonksiyonları göster';
	$lang['strnofunction'] = 'Fonksiyon bulunamadı.';
	$lang['strnofunctions'] = 'Fonksiyon bulunamadı.';
	$lang['strcreateplfunction'] = 'SQL/PL fonksiyonu yarat';
        $lang['strcreateinternalfunction'] = 'İç (internal) fonksiyon yarat';
        $lang['strcreatecfunction'] = 'C fonksiyonu yarat';
	$lang['strfunctionname'] = 'Fonksiyon adı';
	$lang['strreturns'] = 'Dönderilen değer';
	$lang['strarguments'] = 'Argümanlar';
	$lang['strproglanguage'] = 'Dil';
	$lang['strfunctionneedsname'] = 'Fonksiyona bir ad vermelisiniz.';
	$lang['strfunctionneedsdef'] = 'Fonksiyona bir tanım vermelisiniz.';
	$lang['strfunctioncreated'] = 'Fonksiyon yaratıldı.';
	$lang['strfunctioncreatedbad'] = 'Fonksiyon yaratma işlemi başarısız oldu.';
	$lang['strconfdropfunction'] = '"%s" fonksiyonunu kaldırmak istediğinize emin misiniz?';
	$lang['strfunctiondropped'] = 'Fonksiyon kaldırıldı.';
	$lang['strfunctiondroppedbad'] = 'Fonksiyon kaldırma işlemi başarısız oldu.';
	$lang['strfunctionupdated'] = 'Fonksiyon güncellendi.';
	$lang['strfunctionupdatedbad'] = 'Function güncelleme işlemi başarısız oldu.';
	$lang['strobjectfile'] = 'Nesne dosyası';
        $lang['strlinksymbol'] = 'Bağlantı sembolü';

	// Triggers
	$lang['strtrigger'] = 'Trigger';
	$lang['strtriggers'] = 'Triggerlar';
	$lang['strshowalltriggers'] = 'Tüm triggerları göster';
	$lang['strnotrigger'] = 'Trigger bulunamadı.';
	$lang['strnotriggers'] = 'Trigger bulunamadı.';
	$lang['strcreatetrigger'] = 'Yeni trigger yarat';
	$lang['strtriggerneedsname'] = 'Trigger için bir ad belirtmelisiniz.';
	$lang['strtriggerneedsfunc'] = 'Trigger için bir fonksiyon belirtmelisiniz.';
	$lang['strtriggercreated'] = 'Trigger yaratıldı.';
	$lang['strtriggercreatedbad'] = 'Trigger yaratılamadı.';
	$lang['strconfdroptrigger'] = '"%s" triggerini "%s" tablosundan kaldırmak istediğinize emin misiniz?';
	$lang['strtriggerdropped'] = 'Trigger silindi.';
	$lang['strtriggerdroppedbad'] = 'Trigger silinme işlemi başarısız oldu.';
	$lang['strtriggeraltered']  =  'Trigger değiştirildi.';
	$lang['strtriggeralteredbad']  =  'Trigger değiştirilme işlemi başarısız oldu.';
	$lang['strforeach']  =  'Her bir';

	// Types
	$lang['strtype'] = 'Veri tipi';
	$lang['strtypes'] = 'Veri tipleri';
	$lang['strshowalltypes'] = 'Tüm veri tiplerini göster';
	$lang['strnotype'] = 'Hiç veri tipi bulunamadı.';
	$lang['strnotypes'] = 'Hiç veri tipi bulunamadı.';
	$lang['strcreatetype'] = 'Yeni veri tipi yarat';
        $lang['strcreatecomptype'] = 'Karmaşık veri tipi yarat';
        $lang['strtypeneedsfield'] = 'En az bir alan belirtmelisiniz.';
        $lang['strtypeneedscols'] = 'Geçerli bir alan sayısı belirtmelisiniz.';
	$lang['strtypename'] = 'Veri tipi adı';
	$lang['strinputfn'] = 'Giriş (Input) fonksiyonu';
	$lang['stroutputfn'] = 'Çıkış (Output) fonksiyonu';
	$lang['strpassbyval'] = 'Passed by val?';
	$lang['stralignment'] = 'Alignment';
	$lang['strelement'] = 'Eleman';
	$lang['strdelimiter'] = 'Delimiter';
	$lang['strstorage'] = 'Storage';
	$lang['strfield']  =  'Alan';
	$lang['strnumfields']  =  'Alanların sayısı';

	$lang['strtypeneedsname'] = 'Veri tipi için bir ad vermelisiniz.';
	$lang['strtypeneedslen'] = 'Veri tipiniz için bir uzunluk belirtmelisiniz.';
	$lang['strtypecreated'] = 'Veri tipi yaratıldı';
	$lang['strtypecreatedbad'] = 'Veri tipi yaratılamadı.';
	$lang['strconfdroptype'] = '"%s" veri tipini kaldırmak istediğinize emin misiniz?';
	$lang['strtypedropped'] = 'Veri tipi kaldırıldı.';
	$lang['strtypedroppedbad'] = 'Veri tipi kaldırılamadı.';
        $lang['strflavor'] = 'Flavor';
        $lang['strbasetype'] = 'Base';
        $lang['strcompositetype'] = 'Composite';
        $lang['strpseudotype'] = 'Pseudo';

	// Schemas
	$lang['strschema'] = 'Şema';
	$lang['strschemas'] = 'Şemalar';
	$lang['strshowallschemas'] = 'Tüm şemaları göster';
	$lang['strnoschema'] = 'Bir şema bulunamadı.';
	$lang['strnoschemas'] = 'Bir şema bulunamadı.';
	$lang['strcreateschema'] = 'Şema yarat';
	$lang['strschemaname'] = 'Şema adı';
	$lang['strschemaneedsname'] = 'Şema için bir ad belirtmelisiniz.';
	$lang['strschemacreated'] = 'Şema yaratıldı';
	$lang['strschemacreatedbad'] = 'Şema yaratma işlemi başarısız oldu';
	$lang['strconfdropschema'] = '"%s" şemasını kaldırmak istediğinize emin misiniz?';
	$lang['strschemadropped'] = 'Şema kaldırıldı.';
	$lang['strschemadroppedbad'] = 'Şema kaldırma işlemi başarısız oldu.';
	$lang['strschemaaltered']  =  'Schema değiştirildi.';
	$lang['strschemaalteredbad']  =  'Schema değiştirilme işlemi başarısız oldu.';
	$lang['strsearchpath'] = 'Şema arama yolu';

	// Reports
	$lang['strdomain'] = 'Domain';
	$lang['strdomains'] = 'Domainler';
	$lang['strshowalldomains'] = 'Tüm domainleri göster.';
	$lang['strnodomains'] = 'Hiçbir domain bulunamadı.';
	$lang['strcreatedomain'] = 'Domain yarat';
	$lang['strdomaindropped'] = 'Domain silindi.';
	$lang['strdomaindroppedbad'] = 'Domain silme başarısız oldu.';
	$lang['strconfdropdomain'] = '"%s" domain\'ini silmek istediğinize emin misiniz??';
	$lang['strdomainneedsname'] = 'Domain için bir ad vermelisiniz.';
	$lang['strdomaincreated'] = 'Domain yaratıldı.';
	$lang['strdomaincreatedbad'] = 'Domain yaratma başarısız oldu.';
	$lang['strdomainaltered'] = 'Domain alter edildi.';
	$lang['strdomainalteredbad'] = 'Domain alter işlemi başarısız oldu.';

	$lang['stroperator'] = 'Operatör';
	$lang['stroperators']  =  'Operatörler';
	$lang['strshowalloperators'] = 'Tüm operatörleri göster';
	$lang['strnooperator'] = 'Operatör bulunamadı.';
	$lang['strnooperators'] = 'Operatör bulunamadı.';
	$lang['strcreateoperator'] = 'Operatör yaratıldı.';
	$lang['strleftarg'] = 'Sol Arg Tipi';
	$lang['strrightarg'] = 'Sağ Arg Tipi';
	$lang['strcommutator'] = 'Commutator';
	$lang['strnegator'] = 'Negator';
	$lang['strrestrict'] = 'Restrict';
	$lang['strjoin'] = 'Join';
	$lang['strhashes'] = 'Hashes';
	$lang['strmerges'] = 'Merges';
	$lang['strleftsort'] = 'Left sort';
	$lang['strrightsort'] = 'Right sort';
	$lang['strlessthan'] = 'küçüktür';
	$lang['strgreaterthan'] = 'büyüktür';
	$lang['stroperatorneedsname']  =  'Operatöre bir ad vermelisiniz.';
	$lang['stroperatorcreated']  =  'Operatör yaratıldı';
	$lang['stroperatorcreatedbad']  =  'Operatör yaratma işlemi başarısız oldu.';
	$lang['strconfdropoperator']  =  '"%s" operatörünü kaldırmak istediğinize emin misiniz?';
	$lang['stroperatordropped']  =  'Operatör kaldırıldı.';
	$lang['stroperatordroppedbad']  =  'Operator kaldırma işlemi başarısız oldu.';

	// Casts
	$lang['strcasts'] = 'Casts';
	$lang['strnocasts'] = 'Hiç cast bulunamadı.';
	$lang['strsourcetype'] = 'Kaynak tip';
	$lang['strtargettype'] = 'Hedef tip';
	$lang['strimplicit'] = 'Implicit';
	$lang['strinassignment'] = 'In assignment';
	$lang['strbinarycompat'] = '(Binary uyumlu)';
	
	// Conversions
	$lang['strconversions'] = 'Dönüşümleri';
	$lang['strnoconversions'] = 'Hiç dönüşüm bulunamadı.';
	$lang['strsourceencoding'] = 'Kaynak dil kodlaması';
	$lang['strtargetencoding'] = 'Hedef dil kodlaması';
	
	// Languages
	$lang['strlanguages'] = 'Diller';
	$lang['strnolanguages'] = 'Hiç bir dil bulunamadı.';
	$lang['strtrusted'] = 'Güvenilir';
	
	// Info
	$lang['strnoinfo'] = 'Hiç bir bilgi yok.';
	$lang['strreferringtables'] = 'Referring tables';
	$lang['strparenttables'] = 'Parent tablolar';
	$lang['strchildtables'] = 'Child tablolar';
	
	// Aggregates
	$lang['straggregates']  =  'Aggregate';
	$lang['strnoaggregates'] = 'Hiç aggregate bulunamadı.';
	$lang['stralltypes'] = '(Tüm veri tipleri)';
	$lang['stropclasses'] = 'Op sınıfları';
	$lang['strnoopclasses'] = 'Hiç operatör sınıfı bulunamadı.';
	$lang['straccessmethod'] = 'Erişim Yöntemi';
	$lang['strrowperf'] = 'Satır Başarımı';
	$lang['strioperf'] = 'I/O Başarımı';
	$lang['stridxrowperf'] = 'Index Satır Başarımı';
	$lang['stridxioperf'] = 'Index I/O Başarımı';
	$lang['strpercent'] = '%';
	$lang['strsequential'] = 'Sequential';
	$lang['strscan'] = 'Scan';
	$lang['strread'] = 'Read';
	$lang['strfetch'] = 'Fetch';
	$lang['strheap'] = 'Heap';
	$lang['strtoast'] = 'TOAST';
	$lang['strtoastindex'] = 'TOAST Index';
	$lang['strcache'] = 'Cache';
	$lang['strdisk'] = 'Disk';
	$lang['strrows2'] = 'Rows';

	// Tablespaces
	$lang['strtablespace'] = 'Tablespace';
	$lang['strtablespaces'] = 'Tablespaceler';
	$lang['strshowalltablespaces'] = 'Tüm tablespaceleri göster';
	$lang['strnotablespaces'] = 'Hiç tablespace bulunamadı.';
	$lang['strcreatetablespace'] = 'Tablespace yarat';
	$lang['strlocation'] = 'Yer';
	$lang['strtablespaceneedsname'] = 'Tablespace\'e bir ad vermelisiniz.';
	$lang['strtablespaceneedsloc'] = 'Tablespace\'in yaratılacağı dizini belirtmelisiniz';
	$lang['strtablespacecreated'] = 'Tablespace yaratıldı.';
	$lang['strtablespacecreatedbad'] = 'Tablespace yaratılamadı.';
	$lang['strconfdroptablespace'] = '"%s" adlı tablespace\'i kaldırmak istediğinize emin misiniz?';
	$lang['strtablespacedropped'] = 'Tablespace kaldırıldı.';
	$lang['strtablespacedroppedbad'] = 'Tablespace kaldırılamadı.';
	$lang['strtablespacealtered'] = 'Tablespace değiştirildi.';
	$lang['strtablespacealteredbad'] = 'Tablespace değiştirilemedi.';

	// Miscellaneous
	$lang['strtopbar']  =  '%s, %s:%s üzerinde çalışıyor-- "%s" kullanıcısı ile sisteme giriş yaptınız.';
        $lang['strtimefmt']  =  'jS M, Y g:iA';
        $lang['strhelp']  =  'Yardım';
	$lang['strhelpicon'] = '?';
	$lang['strlogintitle']  =  '%s\'e giriş yap';
	$lang['strlogoutmsg']  =  '%s\'den çıkıldı.';
	$lang['strloading']  =  'Yükleniyor...';
	$lang['strerrorloading']  =  'Yükleme hatası';
	$lang['strclicktoreload']  =  'Yeniden yüklemek için tıklayın.';
?>
