<?php
	/**
	 * Hungarian language file for phpPgAdmin.
	 */

	//Basic
	$plugin_lang['strplugindescription'] = 'Report plugin';
	$plugin_lang['strnoreportsdb'] = 'Ön még nem teremtette meg a jelentések adatbázisát. Olvassa el az INSTALL fájlt további útmutatásért!';

	// Reports
	$plugin_lang['strreport'] = 'Jelentés';
	$plugin_lang['strreports'] = 'Jelentések';
	$plugin_lang['strshowallreports'] = 'Minden jelentést megjelenít';
	$plugin_lang['strnoreports'] = 'Nincsenek jelentések.';
	$plugin_lang['strcreatereport'] = 'Jelentést teremt';
	$plugin_lang['strreportdropped'] = 'A jelentés törölve.';
	$plugin_lang['strreportdroppedbad'] = 'Nem sikerült törölni a jelentést.';
	$plugin_lang['strconfdropreport'] = 'Biztosan törölni kívánja „%s” jelentést?';
	$plugin_lang['strreportneedsname'] = 'Meg kell adni a jelentésnevet.';
	$plugin_lang['strreportneedsdef'] = 'SQL kifejezést kell hozzáadni a jelentéshez.';
	$plugin_lang['strreportcreated'] = 'A jelentés megteremtve.';
	$plugin_lang['strreportcreatedbad'] = 'Nem sikerült megteremteni a jelentést.';
?>
